/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 64

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tyTuple__wb7Ftwo1Ba9cOF5RERh5YIg tyTuple__wb7Ftwo1Ba9cOF5RERh5YIg;
typedef struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA;
typedef struct tyObject_SourceMapcolonObjectType___m1S8ZVbfoQLk0xvz8tc6ww tyObject_SourceMapcolonObjectType___m1S8ZVbfoQLk0xvz8tc6ww;
typedef struct tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__KFvl20wcyiCp7mcrl5UXYQ tySequence__KFvl20wcyiCp7mcrl5UXYQ;
typedef struct tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg;
typedef struct tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA;
typedef struct tyTuple__ubXr9bFCXs9bc35NkwsYmx2Q tyTuple__ubXr9bFCXs9bc35NkwsYmx2Q;
typedef struct tyObject_SourceMapGeneratorcolonObjectType___n9aYOgFP19aMaYFJm5zs9bXbw tyObject_SourceMapGeneratorcolonObjectType___n9aYOgFP19aMaYFJm5zs9bXbw;
typedef struct tyObject_Env_sourcemapdotnim_toSourceMap___H4zxRfW3dL8rDu8vpMB6oQ tyObject_Env_sourcemapdotnim_toSourceMap___H4zxRfW3dL8rDu8vpMB6oQ;
typedef struct RootObj RootObj;
typedef struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ;
typedef struct tySequence__9c1n3IOF5T6xvPNf6ipRnuQ tySequence__9c1n3IOF5T6xvPNf6ipRnuQ;
typedef struct tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA;

/* section: NIM_merge_TYPES */
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef N_NIMCALL_PTR(void, tyProc__T4eqaYlFJYZUv9aG9b1TV0bQ) (void);
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
struct tyTuple__wb7Ftwo1Ba9cOF5RERh5YIg {
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* Field0;
tyObject_SourceMapcolonObjectType___m1S8ZVbfoQLk0xvz8tc6ww* Field1;
};
struct tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA {
NI line;
NI column;
NimStringDesc* source;
NimStringDesc* name;
tySequence__KFvl20wcyiCp7mcrl5UXYQ* children;
};
typedef NU8 tyEnum_C__PKpEtWhC9bEPKnEH9bojROKA;
struct tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg {
tyEnum_C__PKpEtWhC9bEPKnEH9bojROKA kind;
union{
struct {tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA* node;
} _kind_1;
struct {NimStringDesc* s;
} _kind_2;
};
};
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
struct tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA {
NI a;
NI b;
};
struct tyTuple__ubXr9bFCXs9bc35NkwsYmx2Q {
NIM_BOOL Field0;
NimStringDesc* Field1;
};
typedef NU8 tyEnum_TokenState__geM5ALFjLh2tNNd8UDdLEw;
struct RootObj {
TNimType* m_type;
};
struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ {
NI Field0;
NI Field1;
};
struct tyObject_Env_sourcemapdotnim_toSourceMap___H4zxRfW3dL8rDu8vpMB6oQ {
  RootObj Sup;
NI colonstate_;
tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA* lastOriginal1;
tyObject_SourceMapGeneratorcolonObjectType___n9aYOgFP19aMaYFJm5zs9bXbw* map2;
tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ generated3;
NIM_BOOL sourceMappingActive4;
};
struct tyObject_SourceMapGeneratorcolonObjectType___n9aYOgFP19aMaYFJm5zs9bXbw {
NimStringDesc* file;
NimStringDesc* sourceRoot;
NIM_BOOL skipValidation;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* sources;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* names;
tySequence__9c1n3IOF5T6xvPNf6ipRnuQ* mappings;
};
struct tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA {
NimStringDesc* source;
tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ original;
tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ generated;
NimStringDesc* name;
NIM_BOOL noSource;
NIM_BOOL noName;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* line, tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA* original, void* ClE_0);
void* ClE_0;
} tyProc__YFZjzhcwazJBtDPYn7K0Rg;
typedef N_CLOSURE_PTR(void, TM__6vuGHHnP4PcSvUQSx0mGGg_16) (NimStringDesc* line, tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA* original);
typedef struct {
N_NIMCALL_PTR(NI, ClP_0) (tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA* x, tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA* y, void* ClE_0);
void* ClE_0;
} tyProc__9apb8PBM2ucUBIVhn3CRrdg;
typedef NU8 tyEnum_SortOrder__8iBc6wlNqBa9cju9cUAhUAxA;
typedef N_CLOSURE_PTR(NI, TM__6vuGHHnP4PcSvUQSx0mGGg_21) (tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA* x, tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA* y, void* ClE_0);
struct tyObject_SourceMapcolonObjectType___m1S8ZVbfoQLk0xvz8tc6ww {
NI version;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* sources;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* names;
NimStringDesc* mappings;
NimStringDesc* file;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__KFvl20wcyiCp7mcrl5UXYQ {
  TGenericSeq Sup;
  tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg* data[SEQ_DECL_SIZE];
};
struct tySequence__9c1n3IOF5T6xvPNf6ipRnuQ {
  TGenericSeq Sup;
  tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA* data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, TM__6vuGHHnP4PcSvUQSx0mGGg_2)(void);
N_LIB_PRIVATE N_NIMCALL(void, nimRegisterGlobalMarker)(tyProc__T4eqaYlFJYZUv9aG9b1TV0bQ markerProc);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);
N_LIB_PRIVATE N_NIMCALL(tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA*, parse__1GlF8FIoxl8Cl9caEwQJitg)(NimStringDesc* source, NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ*, nsuSplitLines)(NimStringDesc* s, NIM_BOOL keepEol);
N_LIB_PRIVATE N_NIMCALL(tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA*, newSourceNode__bbfIRAszPYElHbJ4B0AIYw)(NI line, NI column, NimStringDesc* path, tySequence__KFvl20wcyiCp7mcrl5UXYQ* children, NimStringDesc* name);
static N_NIMCALL(void, Marker_tyRef__lm54M4NIUDvCaS7maOy4lw)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__KFvl20wcyiCp7mcrl5UXYQ)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__kYafIOmoQ4QNaLOPbKBADQ)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void*, newObj)(TNimType* typ, NI size);
N_LIB_PRIVATE N_NIMCALL(void, genericSeqAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuStrip)(NimStringDesc* s, NIM_BOOL leading, NIM_BOOL trailing, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw chars);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsuStartsWith)(NimStringDesc* s, NimStringDesc* prefix);
static N_INLINE(tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg**, X5BX5D___jAIAF54x5JSd8Blqwx3U7Qsystem)(tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg** s, NI sLen_0, NI i);
N_LIB_PRIVATE N_NIMCALL(tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg*, child__OmxnRtQjbdp4HzbhOz3hCA)(NimStringDesc* s);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y);
N_LIB_PRIVATE N_NIMCALL(NI, nsuFindStr)(NimStringDesc* s, NimStringDesc* sub, NI start, NI last);
N_LIB_PRIVATE N_NIMCALL(NI, nsuParseInt)(NimStringDesc* s);
static N_INLINE(NimStringDesc*, X5BX5D___FPvLvuwqfYMFkcbGfPM8QQsystem)(NimStringDesc* s, tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA x);
N_NIMCALL(NimStringDesc*, mnewString)(NI len);
static N_INLINE(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA, dotdot___BokNSDrKN1xmV1nA01G9brAsystem)(NI a, NI b);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size);
static N_INLINE(NimStringDesc*, X5BX5D___ogYTOKbgqbjPfyC123US1gsystem)(NimStringDesc* s, tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA x);
static N_INLINE(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA, dotdot___xNR8BVBMWzS9bXXNMikmyLgsystem)(NI a, NI b);
N_LIB_PRIVATE N_NIMCALL(tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg*, child__TvoO8b39cs63RkA9a5bk9csAw)(tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA* node);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsuIsAlphaAsciiChar)(NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ*, nsuSplitChar)(NimStringDesc* s, NIM_CHAR sep, NI maxsplit);
N_LIB_PRIVATE N_NIMCALL(tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA*, newSourceNode__o6uQhwIheZI9bjPpW9asYaoQ)(NI line, NI column, NimStringDesc* path, NimStringDesc* s, NimStringDesc* name);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqRC1)(TNimType* typ, NI len);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimCharToStr)(NIM_CHAR x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, addChar)(NimStringDesc* s, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsuIsAlphaNumericChar)(NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(tyObject_SourceMapGeneratorcolonObjectType___n9aYOgFP19aMaYFJm5zs9bXbw*, toSourceMap__KIaRadtL8aL8z9bqLINSHYQ)(tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA* node, NimStringDesc* file);
static N_NIMCALL(void, Marker_tyRef__ZiyRAXiRrbEPGtTCmbMS4Q)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__9c1n3IOF5T6xvPNf6ipRnuQ)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__30OItTzKS9b1R09axKKGTwjQ)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__lUKegEKxbmKcVAxqUt9aM5g)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void, walk__OkBmCA3dHlFJKsVSli72Nw)(tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA* node, tyProc__YFZjzhcwazJBtDPYn7K0Rg fn);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___W9c8RE0bbzjhmrRs3LJCDYg)(NimStringDesc* line, tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA* original, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsuEndsWith)(NimStringDesc* s, NimStringDesc* suffix);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(void, addMapping__f1xabsnurMNc3xiNo9cGrIA)(tyObject_SourceMapGeneratorcolonObjectType___n9aYOgFP19aMaYFJm5zs9bXbw* map, tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA* mapping);
static N_INLINE(NIM_BOOL, contains__MghwuKjQqmVLYE8A59cNGHgsystem)(NimStringDesc** a, NI aLen_0, NimStringDesc* item);
static N_INLINE(NI, find__CWgb1wQSxTCKtdHVU5pCYQsystem)(NimStringDesc** a, NI aLen_0, NimStringDesc* item);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, rope__yShmEg9cffWxI7s5XzEKBow)(NimStringDesc* s);
N_NIMCALL(NimStringDesc*, rawNewString)(NI cap);
N_LIB_PRIVATE N_NIMCALL(void, formatValue__3zjq9csYPBcIN7AqvyU5ZLA)(NimStringDesc** result, NimStringDesc* value, NimStringDesc* specifier);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(tyObject_SourceMapcolonObjectType___m1S8ZVbfoQLk0xvz8tc6ww*, gen__NGtoi68ERVEsfzlEwKQBzw)(tyObject_SourceMapGeneratorcolonObjectType___n9aYOgFP19aMaYFJm5zs9bXbw* map);
N_LIB_PRIVATE N_NIMCALL(tySequence__9c1n3IOF5T6xvPNf6ipRnuQ*, sorted__FsvByN47ZdxedyN4Lf9ceiw)(tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA** a, NI aLen_0, tyProc__9apb8PBM2ucUBIVhn3CRrdg cmp, tyEnum_SortOrder__8iBc6wlNqBa9cju9cUAhUAxA order);
N_LIB_PRIVATE N_NIMCALL(NI, colonanonymous___igCpGS9b0Hd5CleN12QuppQ)(tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA* a, tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA* b);
N_LIB_PRIVATE N_NIMCALL(NI, cmp__igCpGS9b0Hd5CleN12QuppQ_2)(tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA* a, tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA* b);
N_LIB_PRIVATE N_NIMCALL(NI, cmp__c3Clqm4S3lJWcp3H9aPZZAA)(tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ x, tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ y);
N_LIB_PRIVATE N_NIMCALL(NI, cmp__NAicU5bAGXmkx2NJujGi7g)(NimStringDesc* x, NimStringDesc* y);
static N_NIMCALL(void, Marker_tyRef__3Qxt9cglO9bmiH9bDHNweKUAA)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ*, X5BX5D___dxs1m8X8HLcMK21WAkRfcw)(NimStringDesc** s, NI sLen_0, tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, serializeMappings__QaiUTEm24bgyLRInBBg9btw)(tyObject_SourceMapGeneratorcolonObjectType___n9aYOgFP19aMaYFJm5zs9bXbw* map, tySequence__9c1n3IOF5T6xvPNf6ipRnuQ* mappings);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, encode__zRPdULeMyp4eFFNp9bPKAOg)(NI i);
N_LIB_PRIVATE N_NIMCALL(NI, index__Vfix5alunq72BVgjEfJQZw)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* elements, NimStringDesc* element);

/* section: NIM_merge_DATA */
extern TNimType NTI__77mFvmsOLKik79ci2hXkHEg_;
STRING_LITERAL(TM__6vuGHHnP4PcSvUQSx0mGGg_3, "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+"
"/=", 65);
N_LIB_PRIVATE TNimType NTI__1kEHpptFknNteceRlFkDjA_;
extern TNimType NTI__rR5Bzr1D5krxoo1NcNyeMA_;
N_LIB_PRIVATE TNimType NTI__bqG0LgcQJ0nO8Yup3buXVg_;
N_LIB_PRIVATE TNimType NTI__PKpEtWhC9bEPKnEH9bojROKA_;
TNimNode* NimDT___bqG0LgcQJ0nO8Yup3buXVg_kind[3];
N_LIB_PRIVATE TNimType NTI__lm54M4NIUDvCaS7maOy4lw_;
N_LIB_PRIVATE TNimType NTI__KFvl20wcyiCp7mcrl5UXYQ_;
N_LIB_PRIVATE TNimType NTI__kYafIOmoQ4QNaLOPbKBADQ_;
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__6vuGHHnP4PcSvUQSx0mGGg_8 = {
0x00, 0x3e, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__6vuGHHnP4PcSvUQSx0mGGg_9, "// line", 7);
STRING_LITERAL(TM__6vuGHHnP4PcSvUQSx0mGGg_10, "\012", 1);
STRING_LITERAL(TM__6vuGHHnP4PcSvUQSx0mGGg_11, " ", 1);
extern TNimType NTI__ytyiCJqK439aF9cIibuRVpAg_;
N_LIB_PRIVATE TNimType NTI__H4zxRfW3dL8rDu8vpMB6oQ_;
extern TNimType NTI__xHTZrq9aYs6boc9bCba0JbpQ_;
N_LIB_PRIVATE TNimType NTI__n9aYOgFP19aMaYFJm5zs9bXbw_;
extern TNimType NTI__VaVACK0bpYmqIQ0mKcHfQQ_;
extern TNimType NTI__sM4lkSb7zS6F7OVMvW9cffQ_;
N_LIB_PRIVATE TNimType NTI__tyoFJJITyZcOtgC4HmERDA_;
extern TNimType NTI__1v9bKyksXWMsm0vNwmZ4EuQ_;
N_LIB_PRIVATE TNimType NTI__ZiyRAXiRrbEPGtTCmbMS4Q_;
N_LIB_PRIVATE TNimType NTI__9c1n3IOF5T6xvPNf6ipRnuQ_;
N_LIB_PRIVATE TNimType NTI__30OItTzKS9b1R09axKKGTwjQ_;
N_LIB_PRIVATE TNimType NTI__lUKegEKxbmKcVAxqUt9aM5g_;
static NIM_CONST tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ TM__6vuGHHnP4PcSvUQSx0mGGg_15 = {((NI) 1),
((NI) 0)}
;
STRING_LITERAL(TM__6vuGHHnP4PcSvUQSx0mGGg_17, ".js", 3);
static NIM_CONST tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ TM__6vuGHHnP4PcSvUQSx0mGGg_18 = {((NI) -1),
((NI) -1)}
;
STRING_LITERAL(TM__6vuGHHnP4PcSvUQSx0mGGg_19, "\012//# sourceMappingURL=", 22);
STRING_LITERAL(TM__6vuGHHnP4PcSvUQSx0mGGg_20, ".map", 4);
N_LIB_PRIVATE TNimType NTI__m1S8ZVbfoQLk0xvz8tc6ww_;
N_LIB_PRIVATE TNimType NTI__3Qxt9cglO9bmiH9bDHNweKUAA_;
static NIM_CONST tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ TM__6vuGHHnP4PcSvUQSx0mGGg_23 = {((NI) 1),
((NI) 0)}
;
static NIM_CONST tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ TM__6vuGHHnP4PcSvUQSx0mGGg_24 = {((NI) 0),
((NI) 0)}
;
STRING_LITERAL(TM__6vuGHHnP4PcSvUQSx0mGGg_25, ";", 1);
STRING_LITERAL(TM__6vuGHHnP4PcSvUQSx0mGGg_26, ",", 1);

/* section: NIM_merge_VARS */
N_LIB_PRIVATE NimStringDesc* integers__uJwQVcAQwCSIvQzV3NHhlA;
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;

/* section: NIM_merge_PROCS */
static N_NIMCALL(void, TM__6vuGHHnP4PcSvUQSx0mGGg_2)(void) {
	nimGCvisit((void*)integers__uJwQVcAQwCSIvQzV3NHhlA, 0);
}
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T1_;
	T1_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(p);
	decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T1_);
}
static N_NIMCALL(void, Marker_tyRef__lm54M4NIUDvCaS7maOy4lw)(void* p, NI op) {
	tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg* a;
	a = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg*)p;
	switch ((*a).kind) {
	case ((tyEnum_C__PKpEtWhC9bEPKnEH9bojROKA) 0):
	nimGCvisit((void*)(*a)._kind_1.node, op);
	break;
	case ((tyEnum_C__PKpEtWhC9bEPKnEH9bojROKA) 1):
	nimGCvisit((void*)(*a)._kind_2.s, op);
	break;
	} 
}
static N_NIMCALL(void, Marker_tySequence__KFvl20wcyiCp7mcrl5UXYQ)(void* p, NI op) {
	tySequence__KFvl20wcyiCp7mcrl5UXYQ* a;
	NI T1_;
	a = (tySequence__KFvl20wcyiCp7mcrl5UXYQ*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_], op);
	}
}
static N_NIMCALL(void, Marker_tyRef__kYafIOmoQ4QNaLOPbKBADQ)(void* p, NI op) {
	tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA* a;
	a = (tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA*)p;
	nimGCvisit((void*)(*a).source, op);
	nimGCvisit((void*)(*a).name, op);
	nimGCvisit((void*)(*a).children, op);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA*, newSourceNode__bbfIRAszPYElHbJ4B0AIYw)(NI line, NI column, NimStringDesc* path, tySequence__KFvl20wcyiCp7mcrl5UXYQ* children, NimStringDesc* name) {
	tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA* result;
	tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA* T1_;
	NimStringDesc* T2_;
	NimStringDesc* T3_;
	result = (tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA*)0;
	T1_ = (tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA*)0;
	T1_ = (tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA*) newObj((&NTI__kYafIOmoQ4QNaLOPbKBADQ_), sizeof(tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA));
	(*T1_).line = line;
	(*T1_).column = column;
	T2_ = (NimStringDesc*)0;
	T2_ = (*T1_).source; (*T1_).source = copyStringRC1(path);
	if (T2_) nimGCunrefNoCycle(T2_);
	T3_ = (NimStringDesc*)0;
	T3_ = (*T1_).name; (*T1_).name = copyStringRC1(name);
	if (T3_) nimGCunrefNoCycle(T3_);
	genericSeqAssign((&(*T1_).children), children, (&NTI__KFvl20wcyiCp7mcrl5UXYQ_));
	result = T1_;
	return result;
}
static N_INLINE(tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg**, X5BX5D___jAIAF54x5JSd8Blqwx3U7Qsystem)(tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg** s, NI sLen_0, NI i) {
	tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg** result;
	result = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg**)0;
	result = &s[(NI)(sLen_0 - i)];
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg*, child__OmxnRtQjbdp4HzbhOz3hCA)(NimStringDesc* s) {
	tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg* result;
	tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg* T1_;
	NimStringDesc* T2_;
	result = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg*)0;
	T1_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg*)0;
	T1_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg*) newObj((&NTI__lm54M4NIUDvCaS7maOy4lw_), sizeof(tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg));
	(*T1_).kind = ((tyEnum_C__PKpEtWhC9bEPKnEH9bojROKA) 1);
	T2_ = (NimStringDesc*)0;
	T2_ = (*T1_)._kind_2.s; (*T1_)._kind_2.s = copyStringRC1(s);
	if (T2_) nimGCunrefNoCycle(T2_);
	result = T1_;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__i80o3k0SgEI5gTRCzYdyWAsystem(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((*c).refcount, ((NI) 8));
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(src);
		incRef__AT1eRuflKWyTTBdLjEDZbg_3system(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem((*dest));
		decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(NimStringDesc*, X5BX5D___FPvLvuwqfYMFkcbGfPM8QQsystem)(NimStringDesc* s, tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA x) {
	NimStringDesc* result;
	NI a;
	NI L;
	result = (NimStringDesc*)0;
	a = x.a;
	L = (NI)((NI)(x.b - a) + ((NI) 1));
	result = mnewString(((NI) (L)));
	{
		NI i;
		NI i_2;
		i = (NI)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < L)) goto LA3;
				i = i_2;
				result->data[i] = s->data[(NI)(i + a)];
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory(p, ((int) 0), size);
}
static N_INLINE(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA, dotdot___BokNSDrKN1xmV1nA01G9brAsystem)(NI a, NI b) {
	tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA result;
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA));
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA));
	result.a = a;
	result.b = b;
	return result;
}
static N_INLINE(NimStringDesc*, X5BX5D___ogYTOKbgqbjPfyC123US1gsystem)(NimStringDesc* s, tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA x) {
	NimStringDesc* result;
	NI a;
	NI L;
	result = (NimStringDesc*)0;
	a = x.a;
	L = (NI)((NI)((NI)((s ? s->Sup.len : 0) - x.b) - a) + ((NI) 1));
	result = mnewString(((NI) (L)));
	{
		NI i;
		NI i_2;
		i = (NI)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < L)) goto LA3;
				i = i_2;
				result->data[i] = s->data[(NI)(i + a)];
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
static N_INLINE(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA, dotdot___xNR8BVBMWzS9bXXNMikmyLgsystem)(NI a, NI b) {
	tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA result;
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA));
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA));
	result.a = a;
	result.b = b;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg*, child__TvoO8b39cs63RkA9a5bk9csAw)(tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA* node) {
	tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg* result;
	tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg* T1_;
	result = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg*)0;
	T1_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg*)0;
	T1_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg*) newObj((&NTI__lm54M4NIUDvCaS7maOy4lw_), sizeof(tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg));
	(*T1_).kind = ((tyEnum_C__PKpEtWhC9bEPKnEH9bojROKA) 0);
	asgnRef((void**) (&(*T1_)._kind_1.node), node);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA*, newSourceNode__o6uQhwIheZI9bjPpW9asYaoQ)(NI line, NI column, NimStringDesc* path, NimStringDesc* s, NimStringDesc* name) {
	tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA* result;
	tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA* T1_;
	NimStringDesc* T2_;
	NimStringDesc* T3_;
	result = (tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA*)0;
	T1_ = (tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA*)0;
	T1_ = (tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA*) newObj((&NTI__kYafIOmoQ4QNaLOPbKBADQ_), sizeof(tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA));
	(*T1_).line = line;
	(*T1_).column = column;
	T2_ = (NimStringDesc*)0;
	T2_ = (*T1_).source; (*T1_).source = copyStringRC1(path);
	if (T2_) nimGCunrefNoCycle(T2_);
	T3_ = (NimStringDesc*)0;
	T3_ = (*T1_).name; (*T1_).name = copyStringRC1(name);
	if (T3_) nimGCunrefNoCycle(T3_);
	if ((*T1_).children) { nimGCunrefNoCycle((*T1_).children); (*T1_).children = NIM_NIL; }
	(*T1_).children = (tySequence__KFvl20wcyiCp7mcrl5UXYQ*) newSeqRC1((&NTI__KFvl20wcyiCp7mcrl5UXYQ_), 1);
	asgnRef((void**) (&(*T1_).children->data[0]), child__OmxnRtQjbdp4HzbhOz3hCA(s));
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA*, parse__1GlF8FIoxl8Cl9caEwQJitg)(NimStringDesc* source, NimStringDesc* path) {
	tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA* result;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
	tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA* lastLocation;
	tySequence__KFvl20wcyiCp7mcrl5UXYQ* T1_;
	result = (tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA*)0;
	lines = nsuSplitLines(source, NIM_FALSE);
	lastLocation = ((tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA*) NIM_NIL);
	T1_ = (tySequence__KFvl20wcyiCp7mcrl5UXYQ*)0;
	T1_ = NIM_NIL;
	result = newSourceNode__bbfIRAszPYElHbJ4B0AIYw(((NI) 0), ((NI) 0), path, T1_, ((NimStringDesc*) NIM_NIL));
	{
		NI i;
		NimStringDesc* originalLine;
		NI i_2;
		NI L;
		NI T3_;
		i = (NI)0;
		originalLine = (NimStringDesc*)0;
		i_2 = ((NI) 0);
		T3_ = (lines ? lines->Sup.len : 0);
		L = T3_;
		{
			while (1) {
				if (!(i_2 < L)) goto LA5;
				i = i_2;
				originalLine = lines->data[i_2];
				{
					NimStringDesc* line;
					line = nsuStrip(originalLine, NIM_TRUE, NIM_TRUE, TM__6vuGHHnP4PcSvUQSx0mGGg_8);
					{
						if (!((line ? line->Sup.len : 0) == ((NI) 0))) goto LA9_;
						goto LA6;
					}
					LA9_: ;
					{
						NIM_BOOL T13_;
						NI pos;
						NI lineNumber;
						tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA T25_;
						NimStringDesc* T26_;
						NimStringDesc* linePath;
						tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA T27_;
						tySequence__KFvl20wcyiCp7mcrl5UXYQ* T28_;
						tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg* T29_;
						NI T30_;
						T13_ = (NIM_BOOL)0;
						T13_ = nsuStartsWith(line, ((NimStringDesc*) &TM__6vuGHHnP4PcSvUQSx0mGGg_9));
						if (!T13_) goto LA14_;
						{
							NI T18_;
							tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg** T21_;
							NimStringDesc* T22_;
							tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg* T23_;
							NI T24_;
							T18_ = ((*result).children ? (*result).children->Sup.len : 0);
							if (!(((NI) 0) < T18_)) goto LA19_;
							T21_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg**)0;
							T21_ = X5BX5D___jAIAF54x5JSd8Blqwx3U7Qsystem((*result).children->data, ((*result).children ? (*result).children->Sup.len : 0), ((NI) 1));
							T22_ = (NimStringDesc*)0;
							T22_ = rawNewString((line ? line->Sup.len : 0) + 1);
appendString(T22_, line);
appendString(T22_, ((NimStringDesc*) &TM__6vuGHHnP4PcSvUQSx0mGGg_10));
							T23_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg*)0;
							T23_ = child__OmxnRtQjbdp4HzbhOz3hCA(T22_);
							asgnRef((void**) (&(*(*(*T21_))._kind_1.node).children), (tySequence__KFvl20wcyiCp7mcrl5UXYQ*) incrSeqV3((TGenericSeq*)((*(*(*T21_))._kind_1.node).children), (&NTI__KFvl20wcyiCp7mcrl5UXYQ_)));
							T24_ = (*(*(*T21_))._kind_1.node).children->Sup.len++;
							asgnRef((void**) (&(*(*(*T21_))._kind_1.node).children->data[T24_]), T23_);
						}
						LA19_: ;
						pos = nsuFindStr(line, ((NimStringDesc*) &TM__6vuGHHnP4PcSvUQSx0mGGg_11), ((NI) 8), ((NI) 0));
						T25_ = dotdot___BokNSDrKN1xmV1nA01G9brAsystem(((NI) 8), (NI)(pos - ((NI) 1)));
						T26_ = (NimStringDesc*)0;
						T26_ = X5BX5D___FPvLvuwqfYMFkcbGfPM8QQsystem(line, T25_);
						lineNumber = nsuParseInt(T26_);
						T27_ = dotdot___xNR8BVBMWzS9bXXNMikmyLgsystem((NI)(pos + ((NI) 2)), ((NI) 2));
						linePath = X5BX5D___ogYTOKbgqbjPfyC123US1gsystem(line, T27_);
						T28_ = (tySequence__KFvl20wcyiCp7mcrl5UXYQ*)0;
						T28_ = NIM_NIL;
						lastLocation = newSourceNode__bbfIRAszPYElHbJ4B0AIYw(lineNumber, ((NI) 0), linePath, T28_, ((NimStringDesc*) NIM_NIL));
						T29_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg*)0;
						T29_ = child__TvoO8b39cs63RkA9a5bk9csAw(lastLocation);
						asgnRef((void**) (&(*result).children), (tySequence__KFvl20wcyiCp7mcrl5UXYQ*) incrSeqV3((TGenericSeq*)((*result).children), (&NTI__KFvl20wcyiCp7mcrl5UXYQ_)));
						T30_ = (*result).children->Sup.len++;
						asgnRef((void**) (&(*result).children->data[T30_]), T29_);
					}
					goto LA11_;
					LA14_: ;
					{
						tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA* last;
						NimStringDesc* nl;
						last = (tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA*)0;
						{
							tyTuple__ubXr9bFCXs9bc35NkwsYmx2Q token;
							tyEnum_TokenState__geM5ALFjLh2tNNd8UDdLEw state;
							NimStringDesc* token_2;
							NIM_BOOL isMangled;
							nimZeroMem((void*)(&token), sizeof(tyTuple__ubXr9bFCXs9bc35NkwsYmx2Q));
							state = ((tyEnum_TokenState__geM5ALFjLh2tNNd8UDdLEw) 0);
							token_2 = ((NimStringDesc*) NIM_NIL);
							isMangled = NIM_FALSE;
							{
								NI z;
								NIM_CHAR ch;
								NI i_3;
								NI L_2;
								z = (NI)0;
								ch = (NIM_CHAR)0;
								i_3 = ((NI) 0);
								L_2 = (line ? line->Sup.len : 0);
								{
									while (1) {
										if (!(i_3 < L_2)) goto LA35;
										z = i_3;
										ch = line->data[i_3];
										{
											NIM_BOOL T38_;
											T38_ = (NIM_BOOL)0;
											T38_ = nsuIsAlphaAsciiChar(ch);
											if (!T38_) goto LA39_;
											{
												if (!(state == ((tyEnum_TokenState__geM5ALFjLh2tNNd8UDdLEw) 0))) goto LA43_;
												state = ((tyEnum_TokenState__geM5ALFjLh2tNNd8UDdLEw) 2);
												{
													NimStringDesc* name;
													if (!(((NI) 0) < (token_2 ? token_2->Sup.len : 0))) goto LA47_;
													token.Field0 = isMangled;
													token.Field1 = copyString(token_2);
													name = ((NimStringDesc*) NIM_NIL);
													{
														tySequence__sM4lkSb7zS6F7OVMvW9cffQ* T53_;
														if (!token.Field0) goto LA51_;
														T53_ = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*)0;
														T53_ = nsuSplitChar(token.Field1, 95, ((NI) 1));
														name = copyString(T53_->data[((NI) 0)]);
													}
													LA51_: ;
													{
														NI T56_;
														tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg** T59_;
														tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg** T60_;
														tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg** T61_;
														tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA* T62_;
														tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg* T63_;
														NI T64_;
														tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg** T65_;
														tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg** T66_;
														T56_ = ((*result).children ? (*result).children->Sup.len : 0);
														if (!(((NI) 0) < T56_)) goto LA57_;
														T59_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg**)0;
														T59_ = X5BX5D___jAIAF54x5JSd8Blqwx3U7Qsystem((*result).children->data, ((*result).children ? (*result).children->Sup.len : 0), ((NI) 1));
														T60_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg**)0;
														T60_ = X5BX5D___jAIAF54x5JSd8Blqwx3U7Qsystem((*result).children->data, ((*result).children ? (*result).children->Sup.len : 0), ((NI) 1));
														T61_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg**)0;
														T61_ = X5BX5D___jAIAF54x5JSd8Blqwx3U7Qsystem((*result).children->data, ((*result).children ? (*result).children->Sup.len : 0), ((NI) 1));
														T62_ = (tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA*)0;
														T62_ = newSourceNode__o6uQhwIheZI9bjPpW9asYaoQ((*(*(*T60_))._kind_1.node).line, ((NI) 0), (*(*(*T61_))._kind_1.node).source, token.Field1, name);
														T63_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg*)0;
														T63_ = child__TvoO8b39cs63RkA9a5bk9csAw(T62_);
														asgnRef((void**) (&(*(*(*T59_))._kind_1.node).children), (tySequence__KFvl20wcyiCp7mcrl5UXYQ*) incrSeqV3((TGenericSeq*)((*(*(*T59_))._kind_1.node).children), (&NTI__KFvl20wcyiCp7mcrl5UXYQ_)));
														T64_ = (*(*(*T59_))._kind_1.node).children->Sup.len++;
														asgnRef((void**) (&(*(*(*T59_))._kind_1.node).children->data[T64_]), T63_);
														T65_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg**)0;
														T65_ = X5BX5D___jAIAF54x5JSd8Blqwx3U7Qsystem((*result).children->data, ((*result).children ? (*result).children->Sup.len : 0), ((NI) 1));
														T66_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg**)0;
														T66_ = X5BX5D___jAIAF54x5JSd8Blqwx3U7Qsystem((*(*(*T65_))._kind_1.node).children->data, ((*(*(*T65_))._kind_1.node).children ? (*(*(*T65_))._kind_1.node).children->Sup.len : 0), ((NI) 1));
														last = (*(*T66_))._kind_1.node;
													}
													goto LA54_;
													LA57_: ;
													{
														tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA* T68_;
														tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg* T69_;
														NI T70_;
														tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg** T71_;
														T68_ = (tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA*)0;
														T68_ = newSourceNode__o6uQhwIheZI9bjPpW9asYaoQ((NI)(i + ((NI) 1)), ((NI) 0), path, token.Field1, name);
														T69_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg*)0;
														T69_ = child__TvoO8b39cs63RkA9a5bk9csAw(T68_);
														asgnRef((void**) (&(*result).children), (tySequence__KFvl20wcyiCp7mcrl5UXYQ*) incrSeqV3((TGenericSeq*)((*result).children), (&NTI__KFvl20wcyiCp7mcrl5UXYQ_)));
														T70_ = (*result).children->Sup.len++;
														asgnRef((void**) (&(*result).children->data[T70_]), T69_);
														T71_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg**)0;
														T71_ = X5BX5D___jAIAF54x5JSd8Blqwx3U7Qsystem((*result).children->data, ((*result).children ? (*result).children->Sup.len : 0), ((NI) 1));
														last = (*(*T71_))._kind_1.node;
													}
													LA54_: ;
												}
												LA47_: ;
												token_2 = nimCharToStr(ch);
												isMangled = NIM_FALSE;
											}
											goto LA41_;
											LA43_: ;
											{
												token_2 = addChar(token_2, ch);
											}
											LA41_: ;
										}
										goto LA36_;
										LA39_: ;
										{
											NimStringDesc* T80_;
											if (!((NU8)(ch) == (NU8)(95))) goto LA74_;
											{
												if (!(state == ((tyEnum_TokenState__geM5ALFjLh2tNNd8UDdLEw) 2))) goto LA78_;
												state = ((tyEnum_TokenState__geM5ALFjLh2tNNd8UDdLEw) 3);
												isMangled = NIM_TRUE;
											}
											LA78_: ;
											T80_ = (NimStringDesc*)0;
											T80_ = nimCharToStr(ch);
											token_2 = resizeString(token_2, (T80_ ? T80_->Sup.len : 0) + 0);
appendString(token_2, T80_);
										}
										goto LA36_;
										LA74_: ;
										{
											NIM_BOOL T82_;
											NIM_BOOL T84_;
											T82_ = (NIM_BOOL)0;
											T82_ = !(((NU8)(ch) == (NU8)(34)));
											if (!(T82_)) goto LA83_;
											T84_ = (NIM_BOOL)0;
											T84_ = nsuIsAlphaNumericChar(ch);
											T82_ = !(T84_);
											LA83_: ;
											if (!T82_) goto LA85_;
											{
												if (!((12 &((NU8)1<<((NU)(state)&7U)))!=0)) goto LA89_;
												state = ((tyEnum_TokenState__geM5ALFjLh2tNNd8UDdLEw) 0);
												{
													NimStringDesc* name_2;
													if (!(((NI) 0) < (token_2 ? token_2->Sup.len : 0))) goto LA93_;
													token.Field0 = isMangled;
													token.Field1 = copyString(token_2);
													name_2 = ((NimStringDesc*) NIM_NIL);
													{
														tySequence__sM4lkSb7zS6F7OVMvW9cffQ* T99_;
														if (!token.Field0) goto LA97_;
														T99_ = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*)0;
														T99_ = nsuSplitChar(token.Field1, 95, ((NI) 1));
														name_2 = copyString(T99_->data[((NI) 0)]);
													}
													LA97_: ;
													{
														NI T102_;
														tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg** T105_;
														tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg** T106_;
														tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg** T107_;
														tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA* T108_;
														tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg* T109_;
														NI T110_;
														tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg** T111_;
														tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg** T112_;
														T102_ = ((*result).children ? (*result).children->Sup.len : 0);
														if (!(((NI) 0) < T102_)) goto LA103_;
														T105_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg**)0;
														T105_ = X5BX5D___jAIAF54x5JSd8Blqwx3U7Qsystem((*result).children->data, ((*result).children ? (*result).children->Sup.len : 0), ((NI) 1));
														T106_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg**)0;
														T106_ = X5BX5D___jAIAF54x5JSd8Blqwx3U7Qsystem((*result).children->data, ((*result).children ? (*result).children->Sup.len : 0), ((NI) 1));
														T107_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg**)0;
														T107_ = X5BX5D___jAIAF54x5JSd8Blqwx3U7Qsystem((*result).children->data, ((*result).children ? (*result).children->Sup.len : 0), ((NI) 1));
														T108_ = (tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA*)0;
														T108_ = newSourceNode__o6uQhwIheZI9bjPpW9asYaoQ((*(*(*T106_))._kind_1.node).line, ((NI) 0), (*(*(*T107_))._kind_1.node).source, token.Field1, name_2);
														T109_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg*)0;
														T109_ = child__TvoO8b39cs63RkA9a5bk9csAw(T108_);
														asgnRef((void**) (&(*(*(*T105_))._kind_1.node).children), (tySequence__KFvl20wcyiCp7mcrl5UXYQ*) incrSeqV3((TGenericSeq*)((*(*(*T105_))._kind_1.node).children), (&NTI__KFvl20wcyiCp7mcrl5UXYQ_)));
														T110_ = (*(*(*T105_))._kind_1.node).children->Sup.len++;
														asgnRef((void**) (&(*(*(*T105_))._kind_1.node).children->data[T110_]), T109_);
														T111_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg**)0;
														T111_ = X5BX5D___jAIAF54x5JSd8Blqwx3U7Qsystem((*result).children->data, ((*result).children ? (*result).children->Sup.len : 0), ((NI) 1));
														T112_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg**)0;
														T112_ = X5BX5D___jAIAF54x5JSd8Blqwx3U7Qsystem((*(*(*T111_))._kind_1.node).children->data, ((*(*(*T111_))._kind_1.node).children ? (*(*(*T111_))._kind_1.node).children->Sup.len : 0), ((NI) 1));
														last = (*(*T112_))._kind_1.node;
													}
													goto LA100_;
													LA103_: ;
													{
														tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA* T114_;
														tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg* T115_;
														NI T116_;
														tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg** T117_;
														T114_ = (tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA*)0;
														T114_ = newSourceNode__o6uQhwIheZI9bjPpW9asYaoQ((NI)(i + ((NI) 1)), ((NI) 0), path, token.Field1, name_2);
														T115_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg*)0;
														T115_ = child__TvoO8b39cs63RkA9a5bk9csAw(T114_);
														asgnRef((void**) (&(*result).children), (tySequence__KFvl20wcyiCp7mcrl5UXYQ*) incrSeqV3((TGenericSeq*)((*result).children), (&NTI__KFvl20wcyiCp7mcrl5UXYQ_)));
														T116_ = (*result).children->Sup.len++;
														asgnRef((void**) (&(*result).children->data[T116_]), T115_);
														T117_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg**)0;
														T117_ = X5BX5D___jAIAF54x5JSd8Blqwx3U7Qsystem((*result).children->data, ((*result).children ? (*result).children->Sup.len : 0), ((NI) 1));
														last = (*(*T117_))._kind_1.node;
													}
													LA100_: ;
												}
												LA93_: ;
												token_2 = nimCharToStr(ch);
												isMangled = NIM_FALSE;
											}
											goto LA87_;
											LA89_: ;
											{
												NimStringDesc* T119_;
												T119_ = (NimStringDesc*)0;
												T119_ = nimCharToStr(ch);
												token_2 = resizeString(token_2, (T119_ ? T119_->Sup.len : 0) + 0);
appendString(token_2, T119_);
											}
											LA87_: ;
										}
										goto LA36_;
										LA85_: ;
										{
											if (!((NU8)(ch) == (NU8)(34))) goto LA121_;
											{
												if (!!((state == ((tyEnum_TokenState__geM5ALFjLh2tNNd8UDdLEw) 1)))) goto LA125_;
												state = ((tyEnum_TokenState__geM5ALFjLh2tNNd8UDdLEw) 1);
												{
													NimStringDesc* name_3;
													if (!(((NI) 0) < (token_2 ? token_2->Sup.len : 0))) goto LA129_;
													token.Field0 = isMangled;
													token.Field1 = copyString(token_2);
													name_3 = ((NimStringDesc*) NIM_NIL);
													{
														tySequence__sM4lkSb7zS6F7OVMvW9cffQ* T135_;
														if (!token.Field0) goto LA133_;
														T135_ = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*)0;
														T135_ = nsuSplitChar(token.Field1, 95, ((NI) 1));
														name_3 = copyString(T135_->data[((NI) 0)]);
													}
													LA133_: ;
													{
														NI T138_;
														tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg** T141_;
														tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg** T142_;
														tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg** T143_;
														tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA* T144_;
														tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg* T145_;
														NI T146_;
														tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg** T147_;
														tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg** T148_;
														T138_ = ((*result).children ? (*result).children->Sup.len : 0);
														if (!(((NI) 0) < T138_)) goto LA139_;
														T141_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg**)0;
														T141_ = X5BX5D___jAIAF54x5JSd8Blqwx3U7Qsystem((*result).children->data, ((*result).children ? (*result).children->Sup.len : 0), ((NI) 1));
														T142_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg**)0;
														T142_ = X5BX5D___jAIAF54x5JSd8Blqwx3U7Qsystem((*result).children->data, ((*result).children ? (*result).children->Sup.len : 0), ((NI) 1));
														T143_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg**)0;
														T143_ = X5BX5D___jAIAF54x5JSd8Blqwx3U7Qsystem((*result).children->data, ((*result).children ? (*result).children->Sup.len : 0), ((NI) 1));
														T144_ = (tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA*)0;
														T144_ = newSourceNode__o6uQhwIheZI9bjPpW9asYaoQ((*(*(*T142_))._kind_1.node).line, ((NI) 0), (*(*(*T143_))._kind_1.node).source, token.Field1, name_3);
														T145_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg*)0;
														T145_ = child__TvoO8b39cs63RkA9a5bk9csAw(T144_);
														asgnRef((void**) (&(*(*(*T141_))._kind_1.node).children), (tySequence__KFvl20wcyiCp7mcrl5UXYQ*) incrSeqV3((TGenericSeq*)((*(*(*T141_))._kind_1.node).children), (&NTI__KFvl20wcyiCp7mcrl5UXYQ_)));
														T146_ = (*(*(*T141_))._kind_1.node).children->Sup.len++;
														asgnRef((void**) (&(*(*(*T141_))._kind_1.node).children->data[T146_]), T145_);
														T147_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg**)0;
														T147_ = X5BX5D___jAIAF54x5JSd8Blqwx3U7Qsystem((*result).children->data, ((*result).children ? (*result).children->Sup.len : 0), ((NI) 1));
														T148_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg**)0;
														T148_ = X5BX5D___jAIAF54x5JSd8Blqwx3U7Qsystem((*(*(*T147_))._kind_1.node).children->data, ((*(*(*T147_))._kind_1.node).children ? (*(*(*T147_))._kind_1.node).children->Sup.len : 0), ((NI) 1));
														last = (*(*T148_))._kind_1.node;
													}
													goto LA136_;
													LA139_: ;
													{
														tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA* T150_;
														tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg* T151_;
														NI T152_;
														tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg** T153_;
														T150_ = (tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA*)0;
														T150_ = newSourceNode__o6uQhwIheZI9bjPpW9asYaoQ((NI)(i + ((NI) 1)), ((NI) 0), path, token.Field1, name_3);
														T151_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg*)0;
														T151_ = child__TvoO8b39cs63RkA9a5bk9csAw(T150_);
														asgnRef((void**) (&(*result).children), (tySequence__KFvl20wcyiCp7mcrl5UXYQ*) incrSeqV3((TGenericSeq*)((*result).children), (&NTI__KFvl20wcyiCp7mcrl5UXYQ_)));
														T152_ = (*result).children->Sup.len++;
														asgnRef((void**) (&(*result).children->data[T152_]), T151_);
														T153_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg**)0;
														T153_ = X5BX5D___jAIAF54x5JSd8Blqwx3U7Qsystem((*result).children->data, ((*result).children ? (*result).children->Sup.len : 0), ((NI) 1));
														last = (*(*T153_))._kind_1.node;
													}
													LA136_: ;
												}
												LA129_: ;
												token_2 = nimCharToStr(ch);
												isMangled = NIM_FALSE;
											}
											goto LA123_;
											LA125_: ;
											{
												NimStringDesc* T155_;
												state = ((tyEnum_TokenState__geM5ALFjLh2tNNd8UDdLEw) 0);
												T155_ = (NimStringDesc*)0;
												T155_ = nimCharToStr(ch);
												token_2 = resizeString(token_2, (T155_ ? T155_->Sup.len : 0) + 0);
appendString(token_2, T155_);
												{
													NimStringDesc* name_4;
													if (!(((NI) 0) < (token_2 ? token_2->Sup.len : 0))) goto LA158_;
													token.Field0 = isMangled;
													token.Field1 = copyString(token_2);
													name_4 = ((NimStringDesc*) NIM_NIL);
													{
														tySequence__sM4lkSb7zS6F7OVMvW9cffQ* T164_;
														if (!token.Field0) goto LA162_;
														T164_ = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*)0;
														T164_ = nsuSplitChar(token.Field1, 95, ((NI) 1));
														name_4 = copyString(T164_->data[((NI) 0)]);
													}
													LA162_: ;
													{
														NI T167_;
														tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg** T170_;
														tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg** T171_;
														tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg** T172_;
														tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA* T173_;
														tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg* T174_;
														NI T175_;
														tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg** T176_;
														tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg** T177_;
														T167_ = ((*result).children ? (*result).children->Sup.len : 0);
														if (!(((NI) 0) < T167_)) goto LA168_;
														T170_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg**)0;
														T170_ = X5BX5D___jAIAF54x5JSd8Blqwx3U7Qsystem((*result).children->data, ((*result).children ? (*result).children->Sup.len : 0), ((NI) 1));
														T171_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg**)0;
														T171_ = X5BX5D___jAIAF54x5JSd8Blqwx3U7Qsystem((*result).children->data, ((*result).children ? (*result).children->Sup.len : 0), ((NI) 1));
														T172_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg**)0;
														T172_ = X5BX5D___jAIAF54x5JSd8Blqwx3U7Qsystem((*result).children->data, ((*result).children ? (*result).children->Sup.len : 0), ((NI) 1));
														T173_ = (tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA*)0;
														T173_ = newSourceNode__o6uQhwIheZI9bjPpW9asYaoQ((*(*(*T171_))._kind_1.node).line, ((NI) 0), (*(*(*T172_))._kind_1.node).source, token.Field1, name_4);
														T174_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg*)0;
														T174_ = child__TvoO8b39cs63RkA9a5bk9csAw(T173_);
														asgnRef((void**) (&(*(*(*T170_))._kind_1.node).children), (tySequence__KFvl20wcyiCp7mcrl5UXYQ*) incrSeqV3((TGenericSeq*)((*(*(*T170_))._kind_1.node).children), (&NTI__KFvl20wcyiCp7mcrl5UXYQ_)));
														T175_ = (*(*(*T170_))._kind_1.node).children->Sup.len++;
														asgnRef((void**) (&(*(*(*T170_))._kind_1.node).children->data[T175_]), T174_);
														T176_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg**)0;
														T176_ = X5BX5D___jAIAF54x5JSd8Blqwx3U7Qsystem((*result).children->data, ((*result).children ? (*result).children->Sup.len : 0), ((NI) 1));
														T177_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg**)0;
														T177_ = X5BX5D___jAIAF54x5JSd8Blqwx3U7Qsystem((*(*(*T176_))._kind_1.node).children->data, ((*(*(*T176_))._kind_1.node).children ? (*(*(*T176_))._kind_1.node).children->Sup.len : 0), ((NI) 1));
														last = (*(*T177_))._kind_1.node;
													}
													goto LA165_;
													LA168_: ;
													{
														tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA* T179_;
														tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg* T180_;
														NI T181_;
														tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg** T182_;
														T179_ = (tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA*)0;
														T179_ = newSourceNode__o6uQhwIheZI9bjPpW9asYaoQ((NI)(i + ((NI) 1)), ((NI) 0), path, token.Field1, name_4);
														T180_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg*)0;
														T180_ = child__TvoO8b39cs63RkA9a5bk9csAw(T179_);
														asgnRef((void**) (&(*result).children), (tySequence__KFvl20wcyiCp7mcrl5UXYQ*) incrSeqV3((TGenericSeq*)((*result).children), (&NTI__KFvl20wcyiCp7mcrl5UXYQ_)));
														T181_ = (*result).children->Sup.len++;
														asgnRef((void**) (&(*result).children->data[T181_]), T180_);
														T182_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg**)0;
														T182_ = X5BX5D___jAIAF54x5JSd8Blqwx3U7Qsystem((*result).children->data, ((*result).children ? (*result).children->Sup.len : 0), ((NI) 1));
														last = (*(*T182_))._kind_1.node;
													}
													LA165_: ;
												}
												LA158_: ;
												isMangled = NIM_FALSE;
												token_2 = ((NimStringDesc*) NIM_NIL);
											}
											LA123_: ;
										}
										goto LA36_;
										LA121_: ;
										{
											NimStringDesc* T184_;
											T184_ = (NimStringDesc*)0;
											T184_ = nimCharToStr(ch);
											token_2 = resizeString(token_2, (T184_ ? T184_->Sup.len : 0) + 0);
appendString(token_2, T184_);
										}
										LA36_: ;
										i_3 += ((NI) 1);
									} LA35: ;
								}
							}
							{
								NimStringDesc* name_5;
								if (!(((NI) 0) < (token_2 ? token_2->Sup.len : 0))) goto LA187_;
								token.Field0 = isMangled;
								token.Field1 = copyString(token_2);
								name_5 = ((NimStringDesc*) NIM_NIL);
								{
									tySequence__sM4lkSb7zS6F7OVMvW9cffQ* T193_;
									if (!token.Field0) goto LA191_;
									T193_ = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*)0;
									T193_ = nsuSplitChar(token.Field1, 95, ((NI) 1));
									name_5 = copyString(T193_->data[((NI) 0)]);
								}
								LA191_: ;
								{
									NI T196_;
									tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg** T199_;
									tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg** T200_;
									tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg** T201_;
									tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA* T202_;
									tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg* T203_;
									NI T204_;
									tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg** T205_;
									tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg** T206_;
									T196_ = ((*result).children ? (*result).children->Sup.len : 0);
									if (!(((NI) 0) < T196_)) goto LA197_;
									T199_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg**)0;
									T199_ = X5BX5D___jAIAF54x5JSd8Blqwx3U7Qsystem((*result).children->data, ((*result).children ? (*result).children->Sup.len : 0), ((NI) 1));
									T200_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg**)0;
									T200_ = X5BX5D___jAIAF54x5JSd8Blqwx3U7Qsystem((*result).children->data, ((*result).children ? (*result).children->Sup.len : 0), ((NI) 1));
									T201_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg**)0;
									T201_ = X5BX5D___jAIAF54x5JSd8Blqwx3U7Qsystem((*result).children->data, ((*result).children ? (*result).children->Sup.len : 0), ((NI) 1));
									T202_ = (tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA*)0;
									T202_ = newSourceNode__o6uQhwIheZI9bjPpW9asYaoQ((*(*(*T200_))._kind_1.node).line, ((NI) 0), (*(*(*T201_))._kind_1.node).source, token.Field1, name_5);
									T203_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg*)0;
									T203_ = child__TvoO8b39cs63RkA9a5bk9csAw(T202_);
									asgnRef((void**) (&(*(*(*T199_))._kind_1.node).children), (tySequence__KFvl20wcyiCp7mcrl5UXYQ*) incrSeqV3((TGenericSeq*)((*(*(*T199_))._kind_1.node).children), (&NTI__KFvl20wcyiCp7mcrl5UXYQ_)));
									T204_ = (*(*(*T199_))._kind_1.node).children->Sup.len++;
									asgnRef((void**) (&(*(*(*T199_))._kind_1.node).children->data[T204_]), T203_);
									T205_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg**)0;
									T205_ = X5BX5D___jAIAF54x5JSd8Blqwx3U7Qsystem((*result).children->data, ((*result).children ? (*result).children->Sup.len : 0), ((NI) 1));
									T206_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg**)0;
									T206_ = X5BX5D___jAIAF54x5JSd8Blqwx3U7Qsystem((*(*(*T205_))._kind_1.node).children->data, ((*(*(*T205_))._kind_1.node).children ? (*(*(*T205_))._kind_1.node).children->Sup.len : 0), ((NI) 1));
									last = (*(*T206_))._kind_1.node;
								}
								goto LA194_;
								LA197_: ;
								{
									tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA* T208_;
									tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg* T209_;
									NI T210_;
									tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg** T211_;
									T208_ = (tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA*)0;
									T208_ = newSourceNode__o6uQhwIheZI9bjPpW9asYaoQ((NI)(i + ((NI) 1)), ((NI) 0), path, token.Field1, name_5);
									T209_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg*)0;
									T209_ = child__TvoO8b39cs63RkA9a5bk9csAw(T208_);
									asgnRef((void**) (&(*result).children), (tySequence__KFvl20wcyiCp7mcrl5UXYQ*) incrSeqV3((TGenericSeq*)((*result).children), (&NTI__KFvl20wcyiCp7mcrl5UXYQ_)));
									T210_ = (*result).children->Sup.len++;
									asgnRef((void**) (&(*result).children->data[T210_]), T209_);
									T211_ = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg**)0;
									T211_ = X5BX5D___jAIAF54x5JSd8Blqwx3U7Qsystem((*result).children->data, ((*result).children ? (*result).children->Sup.len : 0), ((NI) 1));
									last = (*(*T211_))._kind_1.node;
								}
								LA194_: ;
							}
							LA187_: ;
						}
						nl = copyString(((NimStringDesc*) &TM__6vuGHHnP4PcSvUQSx0mGGg_10));
						{
							if (!!((last == 0))) goto LA214_;
							asgnRef((void**) (&(*last).source), resizeString((*last).source, (nl ? nl->Sup.len : 0) + 0));
appendString((*last).source, nl);
						}
						LA214_: ;
					}
					LA11_: ;
				} LA6: ;
				i_2 += ((NI) 1);
			} LA5: ;
		}
	}
	return result;
}
static N_NIMCALL(void, Marker_tyRef__ZiyRAXiRrbEPGtTCmbMS4Q)(void* p, NI op) {
	tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA* a;
	a = (tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA*)p;
	nimGCvisit((void*)(*a).source, op);
	nimGCvisit((void*)(*a).name, op);
}
static N_NIMCALL(void, Marker_tySequence__9c1n3IOF5T6xvPNf6ipRnuQ)(void* p, NI op) {
	tySequence__9c1n3IOF5T6xvPNf6ipRnuQ* a;
	NI T1_;
	a = (tySequence__9c1n3IOF5T6xvPNf6ipRnuQ*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_], op);
	}
}
static N_NIMCALL(void, Marker_tyRef__30OItTzKS9b1R09axKKGTwjQ)(void* p, NI op) {
	tyObject_SourceMapGeneratorcolonObjectType___n9aYOgFP19aMaYFJm5zs9bXbw* a;
	a = (tyObject_SourceMapGeneratorcolonObjectType___n9aYOgFP19aMaYFJm5zs9bXbw*)p;
	nimGCvisit((void*)(*a).file, op);
	nimGCvisit((void*)(*a).sourceRoot, op);
	nimGCvisit((void*)(*a).sources, op);
	nimGCvisit((void*)(*a).names, op);
	nimGCvisit((void*)(*a).mappings, op);
}
static N_NIMCALL(void, Marker_tyRef__lUKegEKxbmKcVAxqUt9aM5g)(void* p, NI op) {
	tyObject_Env_sourcemapdotnim_toSourceMap___H4zxRfW3dL8rDu8vpMB6oQ* a;
	a = (tyObject_Env_sourcemapdotnim_toSourceMap___H4zxRfW3dL8rDu8vpMB6oQ*)p;
	nimGCvisit((void*)(*a).lastOriginal1, op);
	nimGCvisit((void*)(*a).map2, op);
}
N_LIB_PRIVATE N_NIMCALL(void, walk__OkBmCA3dHlFJKsVSli72Nw)(tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA* node, tyProc__YFZjzhcwazJBtDPYn7K0Rg fn) {
	{
		tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg** child;
		NI i;
		NI L;
		NI T2_;
		child = (tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg**)0;
		i = ((NI) 0);
		T2_ = ((*node).children ? (*node).children->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				if (!(i < L)) goto LA4;
				child = &(*node).children->data[i];
				{
					NIM_BOOL T7_;
					T7_ = (NIM_BOOL)0;
					T7_ = ((*(*child)).kind == ((tyEnum_C__PKpEtWhC9bEPKnEH9bojROKA) 1));
					if (!(T7_)) goto LA8_;
					T7_ = (((NI) 0) < ((*(*child))._kind_2.s ? (*(*child))._kind_2.s->Sup.len : 0));
					LA8_: ;
					if (!T7_) goto LA9_;
					fn.ClE_0? fn.ClP_0((*(*child))._kind_2.s, node, fn.ClE_0):((TM__6vuGHHnP4PcSvUQSx0mGGg_16)(fn.ClP_0))((*(*child))._kind_2.s, node);
				}
				goto LA5_;
				LA9_: ;
				{
					walk__OkBmCA3dHlFJKsVSli72Nw((*(*child))._kind_1.node, fn);
				}
				LA5_: ;
				i += ((NI) 1);
			} LA4: ;
		}
	}
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, find__CWgb1wQSxTCKtdHVU5pCYQsystem)(NimStringDesc** a, NI aLen_0, NimStringDesc* item) {
	NI result;
{	result = (NI)0;
	result = ((NI) 0);
	{
		NimStringDesc** i;
		NI i_2;
		i = (NimStringDesc**)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < aLen_0)) goto LA3;
				i = (&a[i_2]);
				{
					if (!eqStrings((*i), item)) goto LA6_;
					goto BeforeRet_;
				}
				LA6_: ;
				result += ((NI) 1);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	result = ((NI) -1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__MghwuKjQqmVLYE8A59cNGHgsystem)(NimStringDesc** a, NI aLen_0, NimStringDesc* item) {
	NIM_BOOL result;
	NI T1_;
{	result = (NIM_BOOL)0;
	T1_ = (NI)0;
	T1_ = find__CWgb1wQSxTCKtdHVU5pCYQsystem(a, aLen_0, item);
	result = (((NI) 0) <= T1_);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addMapping__f1xabsnurMNc3xiNo9cGrIA)(tyObject_SourceMapGeneratorcolonObjectType___n9aYOgFP19aMaYFJm5zs9bXbw* map, tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA* mapping) {
	NI T21_;
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		NI T8_;
		NimStringDesc* T9_;
		T3_ = (NIM_BOOL)0;
		T3_ = !((*mapping).noSource);
		if (!(T3_)) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = contains__MghwuKjQqmVLYE8A59cNGHgsystem((*map).sources->data, ((*map).sources ? (*map).sources->Sup.len : 0), (*mapping).source);
		T3_ = !(T5_);
		LA4_: ;
		if (!T3_) goto LA6_;
		asgnRef((void**) (&(*map).sources), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*map).sources), (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_)));
		T8_ = (*map).sources->Sup.len++;
		T9_ = (NimStringDesc*)0;
		T9_ = (*map).sources->data[T8_]; (*map).sources->data[T8_] = copyStringRC1((*mapping).source);
		if (T9_) nimGCunrefNoCycle(T9_);
	}
	LA6_: ;
	{
		NIM_BOOL T12_;
		NIM_BOOL T13_;
		NIM_BOOL T16_;
		NI T19_;
		NimStringDesc* T20_;
		T12_ = (NIM_BOOL)0;
		T13_ = (NIM_BOOL)0;
		T13_ = !((*mapping).noName);
		if (!(T13_)) goto LA14_;
		T13_ = (((NI) 0) < ((*mapping).name ? (*mapping).name->Sup.len : 0));
		LA14_: ;
		T12_ = T13_;
		if (!(T12_)) goto LA15_;
		T16_ = (NIM_BOOL)0;
		T16_ = contains__MghwuKjQqmVLYE8A59cNGHgsystem((*map).names->data, ((*map).names ? (*map).names->Sup.len : 0), (*mapping).name);
		T12_ = !(T16_);
		LA15_: ;
		if (!T12_) goto LA17_;
		asgnRef((void**) (&(*map).names), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*map).names), (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_)));
		T19_ = (*map).names->Sup.len++;
		T20_ = (NimStringDesc*)0;
		T20_ = (*map).names->data[T19_]; (*map).names->data[T19_] = copyStringRC1((*mapping).name);
		if (T20_) nimGCunrefNoCycle(T20_);
	}
	LA17_: ;
	asgnRef((void**) (&(*map).mappings), (tySequence__9c1n3IOF5T6xvPNf6ipRnuQ*) incrSeqV3((TGenericSeq*)((*map).mappings), (&NTI__9c1n3IOF5T6xvPNf6ipRnuQ_)));
	T21_ = (*map).mappings->Sup.len++;
	asgnRef((void**) (&(*map).mappings->data[T21_]), mapping);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___W9c8RE0bbzjhmrRs3LJCDYg)(NimStringDesc* line, tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA* original, void* ClE_0) {
	tyObject_Env_sourcemapdotnim_toSourceMap___H4zxRfW3dL8rDu8vpMB6oQ* colonenvP_;
	colonenvP_ = (tyObject_Env_sourcemapdotnim_toSourceMap___H4zxRfW3dL8rDu8vpMB6oQ*) ClE_0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nsuEndsWith((*original).source, ((NimStringDesc*) &TM__6vuGHHnP4PcSvUQSx0mGGg_17));
		if (!T3_) goto LA4_;
	}
	goto LA1_;
	LA4_: ;
	{
		{
			tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA* T24_;
			NimStringDesc* T25_;
			NimStringDesc* T26_;
			if (!!(((*original).line == ((NI) -1)))) goto LA9_;
			{
				NIM_BOOL T13_;
				NIM_BOOL T14_;
				NIM_BOOL T15_;
				tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA* T21_;
				NimStringDesc* T22_;
				NimStringDesc* T23_;
				T13_ = (NIM_BOOL)0;
				T14_ = (NIM_BOOL)0;
				T15_ = (NIM_BOOL)0;
				T15_ = !(eqStrings((*(*colonenvP_).lastOriginal1).source, (*original).source));
				if (T15_) goto LA16_;
				T15_ = !(((*(*colonenvP_).lastOriginal1).line == (*original).line));
				LA16_: ;
				T14_ = T15_;
				if (T14_) goto LA17_;
				T14_ = !(((*(*colonenvP_).lastOriginal1).column == (*original).column));
				LA17_: ;
				T13_ = T14_;
				if (T13_) goto LA18_;
				T13_ = !(eqStrings((*(*colonenvP_).lastOriginal1).name, (*original).name));
				LA18_: ;
				if (!T13_) goto LA19_;
				T21_ = (tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA*)0;
				T21_ = (tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA*) newObj((&NTI__ZiyRAXiRrbEPGtTCmbMS4Q_), sizeof(tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA));
				T22_ = (NimStringDesc*)0;
				T22_ = (*T21_).source; (*T21_).source = copyStringRC1((*original).source);
				if (T22_) nimGCunrefNoCycle(T22_);
				(*T21_).original.Field0 = (*original).line;
				(*T21_).original.Field1 = (*original).column;
				(*T21_).generated.Field0 = (*colonenvP_).generated3.Field0;
				(*T21_).generated.Field1 = (*colonenvP_).generated3.Field1;
				T23_ = (NimStringDesc*)0;
				T23_ = (*T21_).name; (*T21_).name = copyStringRC1((*original).name);
				if (T23_) nimGCunrefNoCycle(T23_);
				addMapping__f1xabsnurMNc3xiNo9cGrIA((*colonenvP_).map2, T21_);
			}
			LA19_: ;
			T24_ = (tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA*)0;
			T24_ = (tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA*) newObj((&NTI__kYafIOmoQ4QNaLOPbKBADQ_), sizeof(tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA));
			T25_ = (NimStringDesc*)0;
			T25_ = (*T24_).source; (*T24_).source = copyStringRC1((*original).source);
			if (T25_) nimGCunrefNoCycle(T25_);
			(*T24_).line = (*original).line;
			(*T24_).column = (*original).column;
			T26_ = (NimStringDesc*)0;
			T26_ = (*T24_).name; (*T24_).name = copyStringRC1((*original).name);
			if (T26_) nimGCunrefNoCycle(T26_);
			genericSeqAssign((&(*T24_).children), (*(*colonenvP_).lastOriginal1).children, (&NTI__KFvl20wcyiCp7mcrl5UXYQ_));
			asgnRef((void**) (&(*colonenvP_).lastOriginal1), T24_);
			(*colonenvP_).sourceMappingActive4 = NIM_TRUE;
		}
		goto LA7_;
		LA9_: ;
		{
			tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA* T30_;
			if (!(*colonenvP_).sourceMappingActive4) goto LA28_;
			T30_ = (tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA*)0;
			T30_ = (tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA*) newObj((&NTI__ZiyRAXiRrbEPGtTCmbMS4Q_), sizeof(tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA));
			(*T30_).noSource = NIM_TRUE;
			(*T30_).noName = NIM_TRUE;
			(*T30_).generated.Field0 = (*colonenvP_).generated3.Field0;
			(*T30_).generated.Field1 = (*colonenvP_).generated3.Field1;
			(*T30_).original = TM__6vuGHHnP4PcSvUQSx0mGGg_18;
			addMapping__f1xabsnurMNc3xiNo9cGrIA((*colonenvP_).map2, T30_);
			(*(*colonenvP_).lastOriginal1).line = ((NI) -1);
			(*colonenvP_).sourceMappingActive4 = NIM_FALSE;
		}
		goto LA7_;
		LA28_: ;
		LA7_: ;
	}
	LA1_: ;
	{
		NI z;
		NI colontmp_;
		NI i;
		z = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = (line ? line->Sup.len : 0);
		i = ((NI) 0);
		{
			while (1) {
				if (!(i < colontmp_)) goto LA33;
				z = i;
				{
					if (!(((NU8)(line->data[z])) == ((NU8)(13)) || ((NU8)(line->data[z])) == ((NU8)(10)))) goto LA36_;
					(*colonenvP_).generated3.Field0 += ((NI) 1);
					(*colonenvP_).generated3.Field1 = ((NI) 0);
					{
						if (!(z == (NI)((line ? line->Sup.len : 0) - ((NI) 1)))) goto LA40_;
						(*(*colonenvP_).lastOriginal1).line = ((NI) -1);
						(*colonenvP_).sourceMappingActive4 = NIM_FALSE;
					}
					goto LA38_;
					LA40_: ;
					{
						tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA* T45_;
						NimStringDesc* T46_;
						NimStringDesc* T47_;
						if (!(*colonenvP_).sourceMappingActive4) goto LA43_;
						T45_ = (tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA*)0;
						T45_ = (tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA*) newObj((&NTI__ZiyRAXiRrbEPGtTCmbMS4Q_), sizeof(tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA));
						T46_ = (NimStringDesc*)0;
						T46_ = (*T45_).source; (*T45_).source = copyStringRC1((*original).source);
						if (T46_) nimGCunrefNoCycle(T46_);
						(*T45_).original.Field0 = (*original).line;
						(*T45_).original.Field1 = (*original).column;
						(*T45_).generated.Field0 = (*colonenvP_).generated3.Field0;
						(*T45_).generated.Field1 = (*colonenvP_).generated3.Field1;
						T47_ = (NimStringDesc*)0;
						T47_ = (*T45_).name; (*T45_).name = copyStringRC1((*original).name);
						if (T47_) nimGCunrefNoCycle(T47_);
						addMapping__f1xabsnurMNc3xiNo9cGrIA((*colonenvP_).map2, T45_);
					}
					goto LA38_;
					LA43_: ;
					LA38_: ;
				}
				goto LA34_;
				LA36_: ;
				{
					(*colonenvP_).generated3.Field1 += ((NI) 1);
				}
				LA34_: ;
				i += ((NI) 1);
			} LA33: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_SourceMapGeneratorcolonObjectType___n9aYOgFP19aMaYFJm5zs9bXbw*, toSourceMap__KIaRadtL8aL8z9bqLINSHYQ)(tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA* node, NimStringDesc* file) {
	tyObject_SourceMapGeneratorcolonObjectType___n9aYOgFP19aMaYFJm5zs9bXbw* result;
	tyObject_Env_sourcemapdotnim_toSourceMap___H4zxRfW3dL8rDu8vpMB6oQ* colonenv_;
	tyObject_SourceMapGeneratorcolonObjectType___n9aYOgFP19aMaYFJm5zs9bXbw* T1_;
	NimStringDesc* T2_;
	tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA* T3_;
	tyProc__YFZjzhcwazJBtDPYn7K0Rg T4_;
	result = (tyObject_SourceMapGeneratorcolonObjectType___n9aYOgFP19aMaYFJm5zs9bXbw*)0;
	colonenv_ = (tyObject_Env_sourcemapdotnim_toSourceMap___H4zxRfW3dL8rDu8vpMB6oQ*)0;
	colonenv_ = (tyObject_Env_sourcemapdotnim_toSourceMap___H4zxRfW3dL8rDu8vpMB6oQ*) newObj((&NTI__lUKegEKxbmKcVAxqUt9aM5g_), sizeof(tyObject_Env_sourcemapdotnim_toSourceMap___H4zxRfW3dL8rDu8vpMB6oQ));
	(*colonenv_).Sup.m_type = (&NTI__H4zxRfW3dL8rDu8vpMB6oQ_);
	T1_ = (tyObject_SourceMapGeneratorcolonObjectType___n9aYOgFP19aMaYFJm5zs9bXbw*)0;
	T1_ = (tyObject_SourceMapGeneratorcolonObjectType___n9aYOgFP19aMaYFJm5zs9bXbw*) newObj((&NTI__30OItTzKS9b1R09axKKGTwjQ_), sizeof(tyObject_SourceMapGeneratorcolonObjectType___n9aYOgFP19aMaYFJm5zs9bXbw));
	T2_ = (NimStringDesc*)0;
	T2_ = (*T1_).file; (*T1_).file = copyStringRC1(file);
	if (T2_) nimGCunrefNoCycle(T2_);
	if ((*T1_).sources) { nimGCunrefNoCycle((*T1_).sources); (*T1_).sources = NIM_NIL; }
	if ((*T1_).names) { nimGCunrefNoCycle((*T1_).names); (*T1_).names = NIM_NIL; }
	if ((*T1_).mappings) { nimGCunrefNoCycle((*T1_).mappings); (*T1_).mappings = NIM_NIL; }
	asgnRef((void**) (&(*colonenv_).map2), T1_);
	(*colonenv_).generated3 = TM__6vuGHHnP4PcSvUQSx0mGGg_15;
	(*colonenv_).sourceMappingActive4 = NIM_FALSE;
	T3_ = (tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA*)0;
	T3_ = (tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA*) newObj((&NTI__kYafIOmoQ4QNaLOPbKBADQ_), sizeof(tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA));
	asgnRef((void**) (&(*T3_).source), ((NimStringDesc*) NIM_NIL));
	(*T3_).line = ((NI) -1);
	(*T3_).column = ((NI) 0);
	asgnRef((void**) (&(*T3_).name), ((NimStringDesc*) NIM_NIL));
	if ((*T3_).children) { nimGCunrefNoCycle((*T3_).children); (*T3_).children = NIM_NIL; }
	asgnRef((void**) (&(*colonenv_).lastOriginal1), T3_);
	nimZeroMem((void*)(&T4_), sizeof(tyProc__YFZjzhcwazJBtDPYn7K0Rg));
	T4_.ClP_0 = colonanonymous___W9c8RE0bbzjhmrRs3LJCDYg; T4_.ClE_0 = colonenv_;
	walk__OkBmCA3dHlFJKsVSli72Nw(node, T4_);
	result = (*colonenv_).map2;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, cmp__igCpGS9b0Hd5CleN12QuppQ_2)(tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA* a, tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA* b) {
	NI result;
	NI c;
{	result = (NI)0;
	c = cmp__c3Clqm4S3lJWcp3H9aPZZAA((*a).generated, (*b).generated);
	{
		if (!!((c == ((NI) 0)))) goto LA3_;
		result = c;
		goto BeforeRet_;
	}
	LA3_: ;
	c = cmp__NAicU5bAGXmkx2NJujGi7g((*a).source, (*b).source);
	{
		if (!!((c == ((NI) 0)))) goto LA7_;
		result = c;
		goto BeforeRet_;
	}
	LA7_: ;
	c = cmp__c3Clqm4S3lJWcp3H9aPZZAA((*a).original, (*b).original);
	{
		if (!!((c == ((NI) 0)))) goto LA11_;
		result = c;
		goto BeforeRet_;
	}
	LA11_: ;
	result = cmp__NAicU5bAGXmkx2NJujGi7g((*a).name, (*b).name);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, colonanonymous___igCpGS9b0Hd5CleN12QuppQ)(tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA* a, tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA* b) {
	NI result;
	result = (NI)0;
	result = cmp__igCpGS9b0Hd5CleN12QuppQ_2(a, b);
	return result;
}
static N_NIMCALL(void, Marker_tyRef__3Qxt9cglO9bmiH9bDHNweKUAA)(void* p, NI op) {
	tyObject_SourceMapcolonObjectType___m1S8ZVbfoQLk0xvz8tc6ww* a;
	a = (tyObject_SourceMapcolonObjectType___m1S8ZVbfoQLk0xvz8tc6ww*)p;
	nimGCvisit((void*)(*a).sources, op);
	nimGCvisit((void*)(*a).names, op);
	nimGCvisit((void*)(*a).mappings, op);
	nimGCvisit((void*)(*a).file, op);
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, encode__zRPdULeMyp4eFFNp9bPKAOg)(NI i) {
	NimStringDesc* result;
	NI n;
	NI z;
	result = (NimStringDesc*)0;
	result = ((NimStringDesc*) NIM_NIL);
	n = i;
	{
		if (!(n < ((NI) 0))) goto LA3_;
		n = (NI)((NI)((NU64)(((NI64)-(n))) << (NU64)(((NI) 1))) | ((NI) 1));
	}
	goto LA1_;
	LA3_: ;
	{
		n = (NI)((NU64)(n) << (NU64)(((NI) 1)));
	}
	LA1_: ;
	z = ((NI) 0);
	{
		while (1) {
			NIM_BOOL T8_;
			NI e;
			T8_ = (NIM_BOOL)0;
			T8_ = (z == ((NI) 0));
			if (T8_) goto LA9_;
			T8_ = (((NI) 0) < n);
			LA9_: ;
			if (!T8_) goto LA7;
			e = (NI)(n & ((NI) 31));
			n = (NI)((NI64)(n) >> (NU64)(((NI) 5)));
			{
				if (!(((NI) 0) < n)) goto LA12_;
				e = (NI)(e | ((NI) 32));
			}
			LA12_: ;
			result = addChar(result, integers__uJwQVcAQwCSIvQzV3NHhlA->data[e]);
			z += ((NI) 1);
		} LA7: ;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, index__Vfix5alunq72BVgjEfJQZw)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* elements, NimStringDesc* element) {
	NI result;
{	result = (NI)0;
	{
		NI z;
		NI colontmp_;
		NI T2_;
		NI i;
		z = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (elements ? elements->Sup.len : 0);
		colontmp_ = T2_;
		i = ((NI) 0);
		{
			while (1) {
				if (!(i < colontmp_)) goto LA4;
				z = i;
				{
					if (!eqStrings(elements->data[z], element)) goto LA7_;
					result = z;
					goto BeforeRet_;
				}
				LA7_: ;
				i += ((NI) 1);
			} LA4: ;
		}
	}
	result = ((NI) -1);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, serializeMappings__QaiUTEm24bgyLRInBBg9btw)(tyObject_SourceMapGeneratorcolonObjectType___n9aYOgFP19aMaYFJm5zs9bXbw* map, tySequence__9c1n3IOF5T6xvPNf6ipRnuQ* mappings) {
	NimStringDesc* result;
	tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA* previous;
	tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA* T1_;
	NI previousSourceId;
	NI previousNameId;
	NimStringDesc* next;
	NI nameId;
	NI sourceId;
	result = (NimStringDesc*)0;
	T1_ = (tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA*)0;
	T1_ = (tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA*) newObj((&NTI__ZiyRAXiRrbEPGtTCmbMS4Q_), sizeof(tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA));
	(*T1_).generated = TM__6vuGHHnP4PcSvUQSx0mGGg_23;
	(*T1_).original = TM__6vuGHHnP4PcSvUQSx0mGGg_24;
	asgnRef((void**) (&(*T1_).name), ((NimStringDesc*) NIM_NIL));
	asgnRef((void**) (&(*T1_).source), ((NimStringDesc*) NIM_NIL));
	previous = T1_;
	previousSourceId = ((NI) 0);
	previousNameId = ((NI) 0);
	next = ((NimStringDesc*) NIM_NIL);
	nameId = ((NI) 0);
	sourceId = ((NI) 0);
	result = ((NimStringDesc*) NIM_NIL);
	{
		NI z;
		tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA* mapping;
		NI i;
		NI L;
		NI T3_;
		z = (NI)0;
		mapping = (tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA*)0;
		i = ((NI) 0);
		T3_ = (mappings ? mappings->Sup.len : 0);
		L = T3_;
		{
			while (1) {
				if (!(i < L)) goto LA5;
				z = i;
				mapping = mappings->data[i];
				{
					NimStringDesc* T23_;
					next = ((NimStringDesc*) NIM_NIL);
					{
						if (!!(((*mapping).generated.Field0 == (*previous).generated.Field0))) goto LA9_;
						(*previous).generated.Field1 = ((NI) 0);
						{
							while (1) {
								if (!!(((*mapping).generated.Field0 == (*previous).generated.Field0))) goto LA12;
								next = resizeString(next, 1);
appendString(next, ((NimStringDesc*) &TM__6vuGHHnP4PcSvUQSx0mGGg_25));
								(*previous).generated.Field0 += ((NI) 1);
							} LA12: ;
						}
					}
					goto LA7_;
					LA9_: ;
					{
						{
							if (!(((NI) 0) < z)) goto LA16_;
							{
								NI T20_;
								T20_ = (NI)0;
								T20_ = cmp__igCpGS9b0Hd5CleN12QuppQ_2(mapping, mappings->data[(NI)(z - ((NI) 1))]);
								if (!(T20_ == ((NI) 0))) goto LA21_;
								goto LA6;
							}
							LA21_: ;
							next = resizeString(next, 1);
appendString(next, ((NimStringDesc*) &TM__6vuGHHnP4PcSvUQSx0mGGg_26));
						}
						LA16_: ;
					}
					LA7_: ;
					T23_ = (NimStringDesc*)0;
					T23_ = encode__zRPdULeMyp4eFFNp9bPKAOg((NI)((*mapping).generated.Field1 - (*previous).generated.Field1));
					next = resizeString(next, (T23_ ? T23_->Sup.len : 0) + 0);
appendString(next, T23_);
					(*previous).generated.Field1 = (*mapping).generated.Field1;
					{
						NIM_BOOL T26_;
						NimStringDesc* T30_;
						NimStringDesc* T31_;
						NimStringDesc* T32_;
						T26_ = (NIM_BOOL)0;
						T26_ = !((*mapping).noSource);
						if (!(T26_)) goto LA27_;
						T26_ = (((NI) 0) < ((*mapping).source ? (*mapping).source->Sup.len : 0));
						LA27_: ;
						if (!T26_) goto LA28_;
						sourceId = index__Vfix5alunq72BVgjEfJQZw((*map).sources, (*mapping).source);
						T30_ = (NimStringDesc*)0;
						T30_ = encode__zRPdULeMyp4eFFNp9bPKAOg((NI)(sourceId - previousSourceId));
						next = resizeString(next, (T30_ ? T30_->Sup.len : 0) + 0);
appendString(next, T30_);
						previousSourceId = sourceId;
						T31_ = (NimStringDesc*)0;
						T31_ = encode__zRPdULeMyp4eFFNp9bPKAOg((NI)((NI)((*mapping).original.Field0 - ((NI) 1)) - (*previous).original.Field0));
						next = resizeString(next, (T31_ ? T31_->Sup.len : 0) + 0);
appendString(next, T31_);
						(*previous).original.Field0 = (NI)((*mapping).original.Field0 - ((NI) 1));
						T32_ = (NimStringDesc*)0;
						T32_ = encode__zRPdULeMyp4eFFNp9bPKAOg((NI)((*mapping).original.Field1 - (*previous).original.Field1));
						next = resizeString(next, (T32_ ? T32_->Sup.len : 0) + 0);
appendString(next, T32_);
						(*previous).original.Field1 = (*mapping).original.Field1;
						{
							NIM_BOOL T35_;
							NimStringDesc* T39_;
							T35_ = (NIM_BOOL)0;
							T35_ = !((*mapping).noName);
							if (!(T35_)) goto LA36_;
							T35_ = (((NI) 0) < ((*mapping).name ? (*mapping).name->Sup.len : 0));
							LA36_: ;
							if (!T35_) goto LA37_;
							nameId = index__Vfix5alunq72BVgjEfJQZw((*map).names, (*mapping).name);
							T39_ = (NimStringDesc*)0;
							T39_ = encode__zRPdULeMyp4eFFNp9bPKAOg((NI)(nameId - previousNameId));
							next = resizeString(next, (T39_ ? T39_->Sup.len : 0) + 0);
appendString(next, T39_);
							previousNameId = nameId;
						}
						LA37_: ;
					}
					LA28_: ;
					result = resizeString(result, (next ? next->Sup.len : 0) + 0);
appendString(result, next);
				} LA6: ;
				i += ((NI) 1);
			} LA5: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_SourceMapcolonObjectType___m1S8ZVbfoQLk0xvz8tc6ww*, gen__NGtoi68ERVEsfzlEwKQBzw)(tyObject_SourceMapGeneratorcolonObjectType___n9aYOgFP19aMaYFJm5zs9bXbw* map) {
	tyObject_SourceMapcolonObjectType___m1S8ZVbfoQLk0xvz8tc6ww* result;
	tySequence__9c1n3IOF5T6xvPNf6ipRnuQ* mappings;
	tyProc__9apb8PBM2ucUBIVhn3CRrdg T1_;
	tyObject_SourceMapcolonObjectType___m1S8ZVbfoQLk0xvz8tc6ww* T2_;
	NimStringDesc* T3_;
	tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA T4_;
	tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA T5_;
	result = (tyObject_SourceMapcolonObjectType___m1S8ZVbfoQLk0xvz8tc6ww*)0;
	nimZeroMem((void*)(&T1_), sizeof(tyProc__9apb8PBM2ucUBIVhn3CRrdg));
	T1_.ClP_0 = ((TM__6vuGHHnP4PcSvUQSx0mGGg_21) (colonanonymous___igCpGS9b0Hd5CleN12QuppQ)); T1_.ClE_0 = NIM_NIL;
	mappings = sorted__FsvByN47ZdxedyN4Lf9ceiw((*map).mappings->data, ((*map).mappings ? (*map).mappings->Sup.len : 0), T1_, ((tyEnum_SortOrder__8iBc6wlNqBa9cju9cUAhUAxA) 1));
	T2_ = (tyObject_SourceMapcolonObjectType___m1S8ZVbfoQLk0xvz8tc6ww*)0;
	T2_ = (tyObject_SourceMapcolonObjectType___m1S8ZVbfoQLk0xvz8tc6ww*) newObj((&NTI__3Qxt9cglO9bmiH9bDHNweKUAA_), sizeof(tyObject_SourceMapcolonObjectType___m1S8ZVbfoQLk0xvz8tc6ww));
	T3_ = (NimStringDesc*)0;
	T3_ = (*T2_).file; (*T2_).file = copyStringRC1((*map).file);
	if (T3_) nimGCunrefNoCycle(T3_);
	(*T2_).version = ((NI) 3);
	T4_ = dotdot___xNR8BVBMWzS9bXXNMikmyLgsystem(((NI) 0), ((NI) 1));
	asgnRef((void**) (&(*T2_).sources), X5BX5D___dxs1m8X8HLcMK21WAkRfcw((*map).sources->data, ((*map).sources ? (*map).sources->Sup.len : 0), T4_));
	T5_ = dotdot___xNR8BVBMWzS9bXXNMikmyLgsystem(((NI) 0), ((NI) 1));
	asgnRef((void**) (&(*T2_).names), X5BX5D___dxs1m8X8HLcMK21WAkRfcw((*map).names->data, ((*map).names ? (*map).names->Sup.len : 0), T5_));
	asgnRef((void**) (&(*T2_).mappings), serializeMappings__QaiUTEm24bgyLRInBBg9btw(map, mappings));
	result = T2_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genSourceMap__AhPdyw9b9bcsUwQskMDve3NA)(NimStringDesc* source, NimStringDesc* outFile, tyTuple__wb7Ftwo1Ba9cOF5RERh5YIg* Result) {
	tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA* node;
	tyObject_SourceMapGeneratorcolonObjectType___n9aYOgFP19aMaYFJm5zs9bXbw* map;
	NimStringDesc* fmtRes;
	node = parse__1GlF8FIoxl8Cl9caEwQJitg(source, outFile);
	map = toSourceMap__KIaRadtL8aL8z9bqLINSHYQ(node, outFile);
	fmtRes = rawNewString(((NI) 63));
	formatValue__3zjq9csYPBcIN7AqvyU5ZLA((&fmtRes), source, ((NimStringDesc*) NIM_NIL));
	fmtRes = resizeString(fmtRes, 22);
appendString(fmtRes, ((NimStringDesc*) &TM__6vuGHHnP4PcSvUQSx0mGGg_19));
	formatValue__3zjq9csYPBcIN7AqvyU5ZLA((&fmtRes), outFile, ((NimStringDesc*) NIM_NIL));
	fmtRes = resizeString(fmtRes, 4);
appendString(fmtRes, ((NimStringDesc*) &TM__6vuGHHnP4PcSvUQSx0mGGg_20));
	unsureAsgnRef((void**) (&(*Result).Field0), rope__yShmEg9cffWxI7s5XzEKBow(fmtRes));
	unsureAsgnRef((void**) (&(*Result).Field1), gen__NGtoi68ERVEsfzlEwKQBzw(map));
}
N_LIB_PRIVATE N_NIMCALL(void, compiler_sourcemapInit000)(void) {
{
	NimStringDesc* T1_;

	nimRegisterGlobalMarker(TM__6vuGHHnP4PcSvUQSx0mGGg_2);

	T1_ = (NimStringDesc*)0;
	T1_ = integers__uJwQVcAQwCSIvQzV3NHhlA; integers__uJwQVcAQwCSIvQzV3NHhlA = copyStringRC1(((NimStringDesc*) &TM__6vuGHHnP4PcSvUQSx0mGGg_3));
	if (T1_) nimGCunrefNoCycle(T1_);
}
}

N_LIB_PRIVATE N_NIMCALL(void, compiler_sourcemapDatInit000)(void) {

/* section: NIM_merge_TYPE_INIT1 */
static TNimNode* TM__6vuGHHnP4PcSvUQSx0mGGg_4_5[5];
static TNimNode* TM__6vuGHHnP4PcSvUQSx0mGGg_5_2[2];
NI TM__6vuGHHnP4PcSvUQSx0mGGg_7;
static char* NIM_CONST TM__6vuGHHnP4PcSvUQSx0mGGg_6[2] = {
"cSourceNode", 
"cString"};
static TNimNode* TM__6vuGHHnP4PcSvUQSx0mGGg_12_5[5];
static TNimNode* TM__6vuGHHnP4PcSvUQSx0mGGg_13_6[6];
static TNimNode* TM__6vuGHHnP4PcSvUQSx0mGGg_14_6[6];
static TNimNode* TM__6vuGHHnP4PcSvUQSx0mGGg_22_5[5];
static TNimNode TM__6vuGHHnP4PcSvUQSx0mGGg_0[38];

/* section: NIM_merge_TYPE_INIT3 */
NTI__1kEHpptFknNteceRlFkDjA_.size = sizeof(tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA);
NTI__1kEHpptFknNteceRlFkDjA_.align = NIM_ALIGNOF(tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA);
NTI__1kEHpptFknNteceRlFkDjA_.kind = 18;
NTI__1kEHpptFknNteceRlFkDjA_.base = 0;
TM__6vuGHHnP4PcSvUQSx0mGGg_4_5[0] = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[1];
TM__6vuGHHnP4PcSvUQSx0mGGg_0[1].kind = 1;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[1].offset = offsetof(tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA, line);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[1].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[1].name = "line";
TM__6vuGHHnP4PcSvUQSx0mGGg_4_5[1] = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[2];
TM__6vuGHHnP4PcSvUQSx0mGGg_0[2].kind = 1;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[2].offset = offsetof(tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA, column);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[2].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[2].name = "column";
TM__6vuGHHnP4PcSvUQSx0mGGg_4_5[2] = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[3];
TM__6vuGHHnP4PcSvUQSx0mGGg_0[3].kind = 1;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[3].offset = offsetof(tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA, source);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[3].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[3].name = "source";
TM__6vuGHHnP4PcSvUQSx0mGGg_4_5[3] = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[4];
TM__6vuGHHnP4PcSvUQSx0mGGg_0[4].kind = 1;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[4].offset = offsetof(tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA, name);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[4].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[4].name = "name";
TM__6vuGHHnP4PcSvUQSx0mGGg_4_5[4] = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[5];
NTI__bqG0LgcQJ0nO8Yup3buXVg_.size = sizeof(tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg);
NTI__bqG0LgcQJ0nO8Yup3buXVg_.align = NIM_ALIGNOF(tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg);
NTI__bqG0LgcQJ0nO8Yup3buXVg_.kind = 18;
NTI__bqG0LgcQJ0nO8Yup3buXVg_.base = 0;
NTI__PKpEtWhC9bEPKnEH9bojROKA_.size = sizeof(tyEnum_C__PKpEtWhC9bEPKnEH9bojROKA);
NTI__PKpEtWhC9bEPKnEH9bojROKA_.align = NIM_ALIGNOF(tyEnum_C__PKpEtWhC9bEPKnEH9bojROKA);
NTI__PKpEtWhC9bEPKnEH9bojROKA_.kind = 14;
NTI__PKpEtWhC9bEPKnEH9bojROKA_.base = 0;
NTI__PKpEtWhC9bEPKnEH9bojROKA_.flags = 3;
for (TM__6vuGHHnP4PcSvUQSx0mGGg_7 = 0; TM__6vuGHHnP4PcSvUQSx0mGGg_7 < 2; TM__6vuGHHnP4PcSvUQSx0mGGg_7++) {
TM__6vuGHHnP4PcSvUQSx0mGGg_0[TM__6vuGHHnP4PcSvUQSx0mGGg_7+7].kind = 1;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[TM__6vuGHHnP4PcSvUQSx0mGGg_7+7].offset = TM__6vuGHHnP4PcSvUQSx0mGGg_7;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[TM__6vuGHHnP4PcSvUQSx0mGGg_7+7].name = TM__6vuGHHnP4PcSvUQSx0mGGg_6[TM__6vuGHHnP4PcSvUQSx0mGGg_7];
TM__6vuGHHnP4PcSvUQSx0mGGg_5_2[TM__6vuGHHnP4PcSvUQSx0mGGg_7] = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[TM__6vuGHHnP4PcSvUQSx0mGGg_7+7];
}
TM__6vuGHHnP4PcSvUQSx0mGGg_0[9].len = 2; TM__6vuGHHnP4PcSvUQSx0mGGg_0[9].kind = 2; TM__6vuGHHnP4PcSvUQSx0mGGg_0[9].sons = &TM__6vuGHHnP4PcSvUQSx0mGGg_5_2[0];
NTI__PKpEtWhC9bEPKnEH9bojROKA_.node = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[9];
TM__6vuGHHnP4PcSvUQSx0mGGg_0[6].kind = 3;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[6].offset = offsetof(tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg, kind);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[6].typ = (&NTI__PKpEtWhC9bEPKnEH9bojROKA_);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[6].name = "kind";
TM__6vuGHHnP4PcSvUQSx0mGGg_0[6].sons = &NimDT___bqG0LgcQJ0nO8Yup3buXVg_kind[0];
TM__6vuGHHnP4PcSvUQSx0mGGg_0[6].len = 2;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[10].kind = 1;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[10].offset = offsetof(tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg, _kind_1.node);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[10].typ = (&NTI__kYafIOmoQ4QNaLOPbKBADQ_);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[10].name = "node";
NimDT___bqG0LgcQJ0nO8Yup3buXVg_kind[0] = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[10];
TM__6vuGHHnP4PcSvUQSx0mGGg_0[11].kind = 1;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[11].offset = offsetof(tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg, _kind_2.s);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[11].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[11].name = "s";
NimDT___bqG0LgcQJ0nO8Yup3buXVg_kind[1] = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[11];
NTI__bqG0LgcQJ0nO8Yup3buXVg_.node = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[6];
NTI__lm54M4NIUDvCaS7maOy4lw_.size = sizeof(tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg*);
NTI__lm54M4NIUDvCaS7maOy4lw_.align = NIM_ALIGNOF(tyObject_ChildcolonObjectType___bqG0LgcQJ0nO8Yup3buXVg*);
NTI__lm54M4NIUDvCaS7maOy4lw_.kind = 22;
NTI__lm54M4NIUDvCaS7maOy4lw_.base = (&NTI__bqG0LgcQJ0nO8Yup3buXVg_);
NTI__lm54M4NIUDvCaS7maOy4lw_.marker = Marker_tyRef__lm54M4NIUDvCaS7maOy4lw;
NTI__KFvl20wcyiCp7mcrl5UXYQ_.size = sizeof(tySequence__KFvl20wcyiCp7mcrl5UXYQ*);
NTI__KFvl20wcyiCp7mcrl5UXYQ_.align = NIM_ALIGNOF(tySequence__KFvl20wcyiCp7mcrl5UXYQ*);
NTI__KFvl20wcyiCp7mcrl5UXYQ_.kind = 24;
NTI__KFvl20wcyiCp7mcrl5UXYQ_.base = (&NTI__lm54M4NIUDvCaS7maOy4lw_);
NTI__KFvl20wcyiCp7mcrl5UXYQ_.marker = Marker_tySequence__KFvl20wcyiCp7mcrl5UXYQ;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[5].kind = 1;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[5].offset = offsetof(tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA, children);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[5].typ = (&NTI__KFvl20wcyiCp7mcrl5UXYQ_);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[5].name = "children";
TM__6vuGHHnP4PcSvUQSx0mGGg_0[0].len = 5; TM__6vuGHHnP4PcSvUQSx0mGGg_0[0].kind = 2; TM__6vuGHHnP4PcSvUQSx0mGGg_0[0].sons = &TM__6vuGHHnP4PcSvUQSx0mGGg_4_5[0];
NTI__1kEHpptFknNteceRlFkDjA_.node = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[0];
NTI__kYafIOmoQ4QNaLOPbKBADQ_.size = sizeof(tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA*);
NTI__kYafIOmoQ4QNaLOPbKBADQ_.align = NIM_ALIGNOF(tyObject_SourceNodecolonObjectType___1kEHpptFknNteceRlFkDjA*);
NTI__kYafIOmoQ4QNaLOPbKBADQ_.kind = 22;
NTI__kYafIOmoQ4QNaLOPbKBADQ_.base = (&NTI__1kEHpptFknNteceRlFkDjA_);
NTI__kYafIOmoQ4QNaLOPbKBADQ_.marker = Marker_tyRef__kYafIOmoQ4QNaLOPbKBADQ;
NTI__H4zxRfW3dL8rDu8vpMB6oQ_.size = sizeof(tyObject_Env_sourcemapdotnim_toSourceMap___H4zxRfW3dL8rDu8vpMB6oQ);
NTI__H4zxRfW3dL8rDu8vpMB6oQ_.align = NIM_ALIGNOF(tyObject_Env_sourcemapdotnim_toSourceMap___H4zxRfW3dL8rDu8vpMB6oQ);
NTI__H4zxRfW3dL8rDu8vpMB6oQ_.kind = 17;
NTI__H4zxRfW3dL8rDu8vpMB6oQ_.base = (&NTI__ytyiCJqK439aF9cIibuRVpAg_);
TM__6vuGHHnP4PcSvUQSx0mGGg_12_5[0] = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[13];
TM__6vuGHHnP4PcSvUQSx0mGGg_0[13].kind = 1;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[13].offset = offsetof(tyObject_Env_sourcemapdotnim_toSourceMap___H4zxRfW3dL8rDu8vpMB6oQ, colonstate_);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[13].typ = (&NTI__xHTZrq9aYs6boc9bCba0JbpQ_);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[13].name = ":state";
TM__6vuGHHnP4PcSvUQSx0mGGg_12_5[1] = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[14];
TM__6vuGHHnP4PcSvUQSx0mGGg_0[14].kind = 1;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[14].offset = offsetof(tyObject_Env_sourcemapdotnim_toSourceMap___H4zxRfW3dL8rDu8vpMB6oQ, lastOriginal1);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[14].typ = (&NTI__kYafIOmoQ4QNaLOPbKBADQ_);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[14].name = "lastOriginal1";
TM__6vuGHHnP4PcSvUQSx0mGGg_12_5[2] = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[15];
NTI__n9aYOgFP19aMaYFJm5zs9bXbw_.size = sizeof(tyObject_SourceMapGeneratorcolonObjectType___n9aYOgFP19aMaYFJm5zs9bXbw);
NTI__n9aYOgFP19aMaYFJm5zs9bXbw_.align = NIM_ALIGNOF(tyObject_SourceMapGeneratorcolonObjectType___n9aYOgFP19aMaYFJm5zs9bXbw);
NTI__n9aYOgFP19aMaYFJm5zs9bXbw_.kind = 18;
NTI__n9aYOgFP19aMaYFJm5zs9bXbw_.base = 0;
NTI__n9aYOgFP19aMaYFJm5zs9bXbw_.flags = 2;
TM__6vuGHHnP4PcSvUQSx0mGGg_13_6[0] = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[17];
TM__6vuGHHnP4PcSvUQSx0mGGg_0[17].kind = 1;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[17].offset = offsetof(tyObject_SourceMapGeneratorcolonObjectType___n9aYOgFP19aMaYFJm5zs9bXbw, file);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[17].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[17].name = "file";
TM__6vuGHHnP4PcSvUQSx0mGGg_13_6[1] = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[18];
TM__6vuGHHnP4PcSvUQSx0mGGg_0[18].kind = 1;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[18].offset = offsetof(tyObject_SourceMapGeneratorcolonObjectType___n9aYOgFP19aMaYFJm5zs9bXbw, sourceRoot);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[18].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[18].name = "sourceRoot";
TM__6vuGHHnP4PcSvUQSx0mGGg_13_6[2] = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[19];
TM__6vuGHHnP4PcSvUQSx0mGGg_0[19].kind = 1;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[19].offset = offsetof(tyObject_SourceMapGeneratorcolonObjectType___n9aYOgFP19aMaYFJm5zs9bXbw, skipValidation);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[19].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[19].name = "skipValidation";
TM__6vuGHHnP4PcSvUQSx0mGGg_13_6[3] = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[20];
TM__6vuGHHnP4PcSvUQSx0mGGg_0[20].kind = 1;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[20].offset = offsetof(tyObject_SourceMapGeneratorcolonObjectType___n9aYOgFP19aMaYFJm5zs9bXbw, sources);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[20].typ = (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[20].name = "sources";
TM__6vuGHHnP4PcSvUQSx0mGGg_13_6[4] = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[21];
TM__6vuGHHnP4PcSvUQSx0mGGg_0[21].kind = 1;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[21].offset = offsetof(tyObject_SourceMapGeneratorcolonObjectType___n9aYOgFP19aMaYFJm5zs9bXbw, names);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[21].typ = (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[21].name = "names";
TM__6vuGHHnP4PcSvUQSx0mGGg_13_6[5] = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[22];
NTI__tyoFJJITyZcOtgC4HmERDA_.size = sizeof(tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA);
NTI__tyoFJJITyZcOtgC4HmERDA_.align = NIM_ALIGNOF(tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA);
NTI__tyoFJJITyZcOtgC4HmERDA_.kind = 18;
NTI__tyoFJJITyZcOtgC4HmERDA_.base = 0;
NTI__tyoFJJITyZcOtgC4HmERDA_.flags = 2;
TM__6vuGHHnP4PcSvUQSx0mGGg_14_6[0] = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[24];
TM__6vuGHHnP4PcSvUQSx0mGGg_0[24].kind = 1;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[24].offset = offsetof(tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA, source);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[24].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[24].name = "source";
TM__6vuGHHnP4PcSvUQSx0mGGg_14_6[1] = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[25];
TM__6vuGHHnP4PcSvUQSx0mGGg_0[25].kind = 1;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[25].offset = offsetof(tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA, original);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[25].typ = (&NTI__1v9bKyksXWMsm0vNwmZ4EuQ_);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[25].name = "original";
TM__6vuGHHnP4PcSvUQSx0mGGg_14_6[2] = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[26];
TM__6vuGHHnP4PcSvUQSx0mGGg_0[26].kind = 1;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[26].offset = offsetof(tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA, generated);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[26].typ = (&NTI__1v9bKyksXWMsm0vNwmZ4EuQ_);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[26].name = "generated";
TM__6vuGHHnP4PcSvUQSx0mGGg_14_6[3] = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[27];
TM__6vuGHHnP4PcSvUQSx0mGGg_0[27].kind = 1;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[27].offset = offsetof(tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA, name);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[27].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[27].name = "name";
TM__6vuGHHnP4PcSvUQSx0mGGg_14_6[4] = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[28];
TM__6vuGHHnP4PcSvUQSx0mGGg_0[28].kind = 1;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[28].offset = offsetof(tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA, noSource);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[28].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[28].name = "noSource";
TM__6vuGHHnP4PcSvUQSx0mGGg_14_6[5] = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[29];
TM__6vuGHHnP4PcSvUQSx0mGGg_0[29].kind = 1;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[29].offset = offsetof(tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA, noName);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[29].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[29].name = "noName";
TM__6vuGHHnP4PcSvUQSx0mGGg_0[23].len = 6; TM__6vuGHHnP4PcSvUQSx0mGGg_0[23].kind = 2; TM__6vuGHHnP4PcSvUQSx0mGGg_0[23].sons = &TM__6vuGHHnP4PcSvUQSx0mGGg_14_6[0];
NTI__tyoFJJITyZcOtgC4HmERDA_.node = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[23];
NTI__ZiyRAXiRrbEPGtTCmbMS4Q_.size = sizeof(tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA*);
NTI__ZiyRAXiRrbEPGtTCmbMS4Q_.align = NIM_ALIGNOF(tyObject_MappingcolonObjectType___tyoFJJITyZcOtgC4HmERDA*);
NTI__ZiyRAXiRrbEPGtTCmbMS4Q_.kind = 22;
NTI__ZiyRAXiRrbEPGtTCmbMS4Q_.base = (&NTI__tyoFJJITyZcOtgC4HmERDA_);
NTI__ZiyRAXiRrbEPGtTCmbMS4Q_.flags = 2;
NTI__ZiyRAXiRrbEPGtTCmbMS4Q_.marker = Marker_tyRef__ZiyRAXiRrbEPGtTCmbMS4Q;
NTI__9c1n3IOF5T6xvPNf6ipRnuQ_.size = sizeof(tySequence__9c1n3IOF5T6xvPNf6ipRnuQ*);
NTI__9c1n3IOF5T6xvPNf6ipRnuQ_.align = NIM_ALIGNOF(tySequence__9c1n3IOF5T6xvPNf6ipRnuQ*);
NTI__9c1n3IOF5T6xvPNf6ipRnuQ_.kind = 24;
NTI__9c1n3IOF5T6xvPNf6ipRnuQ_.base = (&NTI__ZiyRAXiRrbEPGtTCmbMS4Q_);
NTI__9c1n3IOF5T6xvPNf6ipRnuQ_.flags = 2;
NTI__9c1n3IOF5T6xvPNf6ipRnuQ_.marker = Marker_tySequence__9c1n3IOF5T6xvPNf6ipRnuQ;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[22].kind = 1;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[22].offset = offsetof(tyObject_SourceMapGeneratorcolonObjectType___n9aYOgFP19aMaYFJm5zs9bXbw, mappings);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[22].typ = (&NTI__9c1n3IOF5T6xvPNf6ipRnuQ_);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[22].name = "mappings";
TM__6vuGHHnP4PcSvUQSx0mGGg_0[16].len = 6; TM__6vuGHHnP4PcSvUQSx0mGGg_0[16].kind = 2; TM__6vuGHHnP4PcSvUQSx0mGGg_0[16].sons = &TM__6vuGHHnP4PcSvUQSx0mGGg_13_6[0];
NTI__n9aYOgFP19aMaYFJm5zs9bXbw_.node = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[16];
NTI__30OItTzKS9b1R09axKKGTwjQ_.size = sizeof(tyObject_SourceMapGeneratorcolonObjectType___n9aYOgFP19aMaYFJm5zs9bXbw*);
NTI__30OItTzKS9b1R09axKKGTwjQ_.align = NIM_ALIGNOF(tyObject_SourceMapGeneratorcolonObjectType___n9aYOgFP19aMaYFJm5zs9bXbw*);
NTI__30OItTzKS9b1R09axKKGTwjQ_.kind = 22;
NTI__30OItTzKS9b1R09axKKGTwjQ_.base = (&NTI__n9aYOgFP19aMaYFJm5zs9bXbw_);
NTI__30OItTzKS9b1R09axKKGTwjQ_.flags = 2;
NTI__30OItTzKS9b1R09axKKGTwjQ_.marker = Marker_tyRef__30OItTzKS9b1R09axKKGTwjQ;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[15].kind = 1;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[15].offset = offsetof(tyObject_Env_sourcemapdotnim_toSourceMap___H4zxRfW3dL8rDu8vpMB6oQ, map2);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[15].typ = (&NTI__30OItTzKS9b1R09axKKGTwjQ_);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[15].name = "map2";
TM__6vuGHHnP4PcSvUQSx0mGGg_12_5[3] = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[30];
TM__6vuGHHnP4PcSvUQSx0mGGg_0[30].kind = 1;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[30].offset = offsetof(tyObject_Env_sourcemapdotnim_toSourceMap___H4zxRfW3dL8rDu8vpMB6oQ, generated3);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[30].typ = (&NTI__1v9bKyksXWMsm0vNwmZ4EuQ_);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[30].name = "generated3";
TM__6vuGHHnP4PcSvUQSx0mGGg_12_5[4] = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[31];
TM__6vuGHHnP4PcSvUQSx0mGGg_0[31].kind = 1;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[31].offset = offsetof(tyObject_Env_sourcemapdotnim_toSourceMap___H4zxRfW3dL8rDu8vpMB6oQ, sourceMappingActive4);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[31].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[31].name = "sourceMappingActive4";
TM__6vuGHHnP4PcSvUQSx0mGGg_0[12].len = 5; TM__6vuGHHnP4PcSvUQSx0mGGg_0[12].kind = 2; TM__6vuGHHnP4PcSvUQSx0mGGg_0[12].sons = &TM__6vuGHHnP4PcSvUQSx0mGGg_12_5[0];
NTI__H4zxRfW3dL8rDu8vpMB6oQ_.node = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[12];
NTI__lUKegEKxbmKcVAxqUt9aM5g_.size = sizeof(tyObject_Env_sourcemapdotnim_toSourceMap___H4zxRfW3dL8rDu8vpMB6oQ*);
NTI__lUKegEKxbmKcVAxqUt9aM5g_.align = NIM_ALIGNOF(tyObject_Env_sourcemapdotnim_toSourceMap___H4zxRfW3dL8rDu8vpMB6oQ*);
NTI__lUKegEKxbmKcVAxqUt9aM5g_.kind = 22;
NTI__lUKegEKxbmKcVAxqUt9aM5g_.base = (&NTI__H4zxRfW3dL8rDu8vpMB6oQ_);
NTI__lUKegEKxbmKcVAxqUt9aM5g_.marker = Marker_tyRef__lUKegEKxbmKcVAxqUt9aM5g;
NTI__m1S8ZVbfoQLk0xvz8tc6ww_.size = sizeof(tyObject_SourceMapcolonObjectType___m1S8ZVbfoQLk0xvz8tc6ww);
NTI__m1S8ZVbfoQLk0xvz8tc6ww_.align = NIM_ALIGNOF(tyObject_SourceMapcolonObjectType___m1S8ZVbfoQLk0xvz8tc6ww);
NTI__m1S8ZVbfoQLk0xvz8tc6ww_.kind = 18;
NTI__m1S8ZVbfoQLk0xvz8tc6ww_.base = 0;
NTI__m1S8ZVbfoQLk0xvz8tc6ww_.flags = 2;
TM__6vuGHHnP4PcSvUQSx0mGGg_22_5[0] = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[33];
TM__6vuGHHnP4PcSvUQSx0mGGg_0[33].kind = 1;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[33].offset = offsetof(tyObject_SourceMapcolonObjectType___m1S8ZVbfoQLk0xvz8tc6ww, version);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[33].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[33].name = "version";
TM__6vuGHHnP4PcSvUQSx0mGGg_22_5[1] = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[34];
TM__6vuGHHnP4PcSvUQSx0mGGg_0[34].kind = 1;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[34].offset = offsetof(tyObject_SourceMapcolonObjectType___m1S8ZVbfoQLk0xvz8tc6ww, sources);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[34].typ = (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[34].name = "sources";
TM__6vuGHHnP4PcSvUQSx0mGGg_22_5[2] = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[35];
TM__6vuGHHnP4PcSvUQSx0mGGg_0[35].kind = 1;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[35].offset = offsetof(tyObject_SourceMapcolonObjectType___m1S8ZVbfoQLk0xvz8tc6ww, names);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[35].typ = (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[35].name = "names";
TM__6vuGHHnP4PcSvUQSx0mGGg_22_5[3] = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[36];
TM__6vuGHHnP4PcSvUQSx0mGGg_0[36].kind = 1;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[36].offset = offsetof(tyObject_SourceMapcolonObjectType___m1S8ZVbfoQLk0xvz8tc6ww, mappings);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[36].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[36].name = "mappings";
TM__6vuGHHnP4PcSvUQSx0mGGg_22_5[4] = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[37];
TM__6vuGHHnP4PcSvUQSx0mGGg_0[37].kind = 1;
TM__6vuGHHnP4PcSvUQSx0mGGg_0[37].offset = offsetof(tyObject_SourceMapcolonObjectType___m1S8ZVbfoQLk0xvz8tc6ww, file);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[37].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__6vuGHHnP4PcSvUQSx0mGGg_0[37].name = "file";
TM__6vuGHHnP4PcSvUQSx0mGGg_0[32].len = 5; TM__6vuGHHnP4PcSvUQSx0mGGg_0[32].kind = 2; TM__6vuGHHnP4PcSvUQSx0mGGg_0[32].sons = &TM__6vuGHHnP4PcSvUQSx0mGGg_22_5[0];
NTI__m1S8ZVbfoQLk0xvz8tc6ww_.node = &TM__6vuGHHnP4PcSvUQSx0mGGg_0[32];
NTI__3Qxt9cglO9bmiH9bDHNweKUAA_.size = sizeof(tyObject_SourceMapcolonObjectType___m1S8ZVbfoQLk0xvz8tc6ww*);
NTI__3Qxt9cglO9bmiH9bDHNweKUAA_.align = NIM_ALIGNOF(tyObject_SourceMapcolonObjectType___m1S8ZVbfoQLk0xvz8tc6ww*);
NTI__3Qxt9cglO9bmiH9bDHNweKUAA_.kind = 22;
NTI__3Qxt9cglO9bmiH9bDHNweKUAA_.base = (&NTI__m1S8ZVbfoQLk0xvz8tc6ww_);
NTI__3Qxt9cglO9bmiH9bDHNweKUAA_.flags = 2;
NTI__3Qxt9cglO9bmiH9bDHNweKUAA_.marker = Marker_tyRef__3Qxt9cglO9bmiH9bDHNweKUAA;
}

